(function (factory) {
	typeof define === 'function' && define.amd ? define(factory) :
	factory();
}((function () { 'use strict';

	/**
	 * domReady 2.0.1 Copyright jQuery Foundation and other contributors.
	 * Released under MIT license, http://github.com/requirejs/domReady/LICENSE
	 */

	/*jslint */

	/*global require: false, define: false, requirejs: false,
	  window: false, clearInterval: false, document: false,
	  self: false, setInterval: false */
	var isTop,
	    testDiv,
	    scrollIntervalId,
	    isBrowser = typeof window !== "undefined" && window.document,
	    isPageLoaded = !isBrowser,
	    doc = isBrowser ? document : null,
	    readyCalls = [];

	function runCallbacks(callbacks) {
	  var i;

	  for (i = 0; i < callbacks.length; i += 1) {
	    callbacks[i](doc);
	  }
	}

	function callReady() {
	  var callbacks = readyCalls;

	  if (isPageLoaded) {
	    //Call the DOM ready callbacks
	    if (callbacks.length) {
	      readyCalls = [];
	      runCallbacks(callbacks);
	    }
	  }
	}
	/**
	 * Sets the page as loaded.
	 */


	function pageLoaded() {
	  if (!isPageLoaded) {
	    isPageLoaded = true;

	    if (scrollIntervalId) {
	      clearInterval(scrollIntervalId);
	    }

	    callReady();
	  }
	}

	if (isBrowser) {
	  if (document.addEventListener) {
	    //Standards. Hooray! Assumption here that if standards based,
	    //it knows about DOMContentLoaded.
	    document.addEventListener("DOMContentLoaded", pageLoaded, false);
	    window.addEventListener("load", pageLoaded, false);
	  } else if (window.attachEvent) {
	    window.attachEvent("onload", pageLoaded);
	    testDiv = document.createElement('div');

	    try {
	      isTop = window.frameElement === null;
	    } catch (e) {} //DOMContentLoaded approximation that uses a doScroll, as found by
	    //Diego Perini: http://javascript.nwbox.com/IEContentLoaded/,
	    //but modified by other contributors, including jdalton


	    if (testDiv.doScroll && isTop && window.external) {
	      scrollIntervalId = setInterval(function () {
	        try {
	          testDiv.doScroll();
	          pageLoaded();
	        } catch (e) {}
	      }, 30);
	    }
	  } //Check if document already complete, and if so, just trigger page load
	  //listeners. Latest webkit browsers also use "interactive", and
	  //will fire the onDOMContentLoaded before "interactive" but not after
	  //entering "interactive" or "complete". More details:
	  //http://dev.w3.org/html5/spec/the-end.html#the-end
	  //http://stackoverflow.com/questions/3665561/document-readystate-of-interactive-vs-ondomcontentloaded
	  //Hmm, this is more complicated on further use, see "firing too early"
	  //bug: https://github.com/requirejs/domReady/issues/1
	  //so removing the || document.readyState === "interactive" test.
	  //There is still a window.onload binding that should get fired if
	  //DOMContentLoaded is missed.


	  if (document.readyState === "complete") {
	    pageLoaded();
	  }
	}
	/** START OF PUBLIC API **/

	/**
	 * Registers a callback for DOM ready. If DOM is already ready, the
	 * callback is called immediately.
	 * @param {Function} callback
	 */


	function domReady(callback) {
	  if (isPageLoaded) {
	    callback(doc);
	  } else {
	    readyCalls.push(callback);
	  }

	  return domReady;
	}

	domReady.version = '2.0.1';
	/**
	 * Loader Plugin API method
	 */

	domReady.load = function (name, req, onLoad, config) {
	  if (config.isBuild) {
	    onLoad(null);
	  } else {
	    domReady(onLoad);
	  }
	};

	function _typeof(obj) {
	  "@babel/helpers - typeof";

	  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
	    _typeof = function (obj) {
	      return typeof obj;
	    };
	  } else {
	    _typeof = function (obj) {
	      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
	    };
	  }

	  return _typeof(obj);
	}

	function _classCallCheck(instance, Constructor) {
	  if (!(instance instanceof Constructor)) {
	    throw new TypeError("Cannot call a class as a function");
	  }
	}

	function _defineProperties(target, props) {
	  for (var i = 0; i < props.length; i++) {
	    var descriptor = props[i];
	    descriptor.enumerable = descriptor.enumerable || false;
	    descriptor.configurable = true;
	    if ("value" in descriptor) descriptor.writable = true;
	    Object.defineProperty(target, descriptor.key, descriptor);
	  }
	}

	function _createClass(Constructor, protoProps, staticProps) {
	  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
	  if (staticProps) _defineProperties(Constructor, staticProps);
	  return Constructor;
	}

	function _defineProperty(obj, key, value) {
	  if (key in obj) {
	    Object.defineProperty(obj, key, {
	      value: value,
	      enumerable: true,
	      configurable: true,
	      writable: true
	    });
	  } else {
	    obj[key] = value;
	  }

	  return obj;
	}

	function ownKeys(object, enumerableOnly) {
	  var keys = Object.keys(object);

	  if (Object.getOwnPropertySymbols) {
	    var symbols = Object.getOwnPropertySymbols(object);
	    if (enumerableOnly) symbols = symbols.filter(function (sym) {
	      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
	    });
	    keys.push.apply(keys, symbols);
	  }

	  return keys;
	}

	function _objectSpread2(target) {
	  for (var i = 1; i < arguments.length; i++) {
	    var source = arguments[i] != null ? arguments[i] : {};

	    if (i % 2) {
	      ownKeys(Object(source), true).forEach(function (key) {
	        _defineProperty(target, key, source[key]);
	      });
	    } else if (Object.getOwnPropertyDescriptors) {
	      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
	    } else {
	      ownKeys(Object(source)).forEach(function (key) {
	        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
	      });
	    }
	  }

	  return target;
	}

	function _slicedToArray(arr, i) {
	  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
	}

	function _toConsumableArray(arr) {
	  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
	}

	function _arrayWithoutHoles(arr) {
	  if (Array.isArray(arr)) return _arrayLikeToArray(arr);
	}

	function _arrayWithHoles(arr) {
	  if (Array.isArray(arr)) return arr;
	}

	function _iterableToArray(iter) {
	  if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter);
	}

	function _iterableToArrayLimit(arr, i) {
	  if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return;
	  var _arr = [];
	  var _n = true;
	  var _d = false;
	  var _e = undefined;

	  try {
	    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
	      _arr.push(_s.value);

	      if (i && _arr.length === i) break;
	    }
	  } catch (err) {
	    _d = true;
	    _e = err;
	  } finally {
	    try {
	      if (!_n && _i["return"] != null) _i["return"]();
	    } finally {
	      if (_d) throw _e;
	    }
	  }

	  return _arr;
	}

	function _unsupportedIterableToArray(o, minLen) {
	  if (!o) return;
	  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
	  var n = Object.prototype.toString.call(o).slice(8, -1);
	  if (n === "Object" && o.constructor) n = o.constructor.name;
	  if (n === "Map" || n === "Set") return Array.from(n);
	  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
	}

	function _arrayLikeToArray(arr, len) {
	  if (len == null || len > arr.length) len = arr.length;

	  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

	  return arr2;
	}

	function _nonIterableSpread() {
	  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
	}

	function _nonIterableRest() {
	  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
	}

	function _createForOfIteratorHelper(o) {
	  if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) {
	    if (Array.isArray(o) || (o = _unsupportedIterableToArray(o))) {
	      var i = 0;

	      var F = function () {};

	      return {
	        s: F,
	        n: function () {
	          if (i >= o.length) return {
	            done: true
	          };
	          return {
	            done: false,
	            value: o[i++]
	          };
	        },
	        e: function (e) {
	          throw e;
	        },
	        f: F
	      };
	    }

	    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
	  }

	  var it,
	      normalCompletion = true,
	      didErr = false,
	      err;
	  return {
	    s: function () {
	      it = o[Symbol.iterator]();
	    },
	    n: function () {
	      var step = it.next();
	      normalCompletion = step.done;
	      return step;
	    },
	    e: function (e) {
	      didErr = true;
	      err = e;
	    },
	    f: function () {
	      try {
	        if (!normalCompletion && it.return != null) it.return();
	      } finally {
	        if (didErr) throw err;
	      }
	    }
	  };
	}

	// adapted from https://github.com/WICG/EventListenerOptions/blob/gh-pages/explainer.md
	var detectPassiveEvents = {
	  update: function update() {
	    if (typeof window !== 'undefined' && typeof window.addEventListener === 'function') {
	      var passive = false;
	      var options = Object.defineProperty({}, 'passive', {
	        get: function get() {
	          passive = true;
	        }
	      }); // note: have to set and remove a no-op listener instead of null
	      // (which was used previously), becasue Edge v15 throws an error
	      // when providing a null callback.
	      // https://github.com/rafrex/detect-passive-events/pull/3

	      var noop = function noop() {};

	      window.addEventListener('testPassiveEventSupport', noop, options);
	      window.removeEventListener('testPassiveEventSupport', noop, options);
	      detectPassiveEvents.hasSupport = passive;
	    }
	  }
	};
	detectPassiveEvents.update();

	/* eslint-disable no-undefined,no-param-reassign,no-shadow */

	/**
	 * Throttle execution of a function. Especially useful for rate limiting
	 * execution of handlers on events like resize and scroll.
	 *
	 * @param  {Number}    delay          A zero-or-greater delay in milliseconds. For event callbacks, values around 100 or 250 (or even higher) are most useful.
	 * @param  {Boolean}   [noTrailing]   Optional, defaults to false. If noTrailing is true, callback will only execute every `delay` milliseconds while the
	 *                                    throttled-function is being called. If noTrailing is false or unspecified, callback will be executed one final time
	 *                                    after the last throttled-function call. (After the throttled-function has not been called for `delay` milliseconds,
	 *                                    the internal counter is reset)
	 * @param  {Function}  callback       A function to be executed after delay milliseconds. The `this` context and all arguments are passed through, as-is,
	 *                                    to `callback` when the throttled-function is executed.
	 * @param  {Boolean}   [debounceMode] If `debounceMode` is true (at begin), schedule `clear` to execute after `delay` ms. If `debounceMode` is false (at end),
	 *                                    schedule `callback` to execute after `delay` ms.
	 *
	 * @return {Function}  A new, throttled, function.
	 */
	function throttle (delay, noTrailing, callback, debounceMode) {
	  /*
	   * After wrapper has stopped being called, this timeout ensures that
	   * `callback` is executed at the proper times in `throttle` and `end`
	   * debounce modes.
	   */
	  var timeoutID;
	  var cancelled = false; // Keep track of the last time `callback` was executed.

	  var lastExec = 0; // Function to clear existing timeout

	  function clearExistingTimeout() {
	    if (timeoutID) {
	      clearTimeout(timeoutID);
	    }
	  } // Function to cancel next exec


	  function cancel() {
	    clearExistingTimeout();
	    cancelled = true;
	  } // `noTrailing` defaults to falsy.


	  if (typeof noTrailing !== 'boolean') {
	    debounceMode = callback;
	    callback = noTrailing;
	    noTrailing = undefined;
	  }
	  /*
	   * The `wrapper` function encapsulates all of the throttling / debouncing
	   * functionality and when executed will limit the rate at which `callback`
	   * is executed.
	   */


	  function wrapper() {
	    var self = this;
	    var elapsed = Date.now() - lastExec;
	    var args = arguments;

	    if (cancelled) {
	      return;
	    } // Execute `callback` and update the `lastExec` timestamp.


	    function exec() {
	      lastExec = Date.now();
	      callback.apply(self, args);
	    }
	    /*
	     * If `debounceMode` is true (at begin) this is used to clear the flag
	     * to allow future `callback` executions.
	     */


	    function clear() {
	      timeoutID = undefined;
	    }

	    if (debounceMode && !timeoutID) {
	      /*
	       * Since `wrapper` is being called for the first time and
	       * `debounceMode` is true (at begin), execute `callback`.
	       */
	      exec();
	    }

	    clearExistingTimeout();

	    if (debounceMode === undefined && elapsed > delay) {
	      /*
	       * In throttle mode, if `delay` time has been exceeded, execute
	       * `callback`.
	       */
	      exec();
	    } else if (noTrailing !== true) {
	      /*
	       * In trailing throttle mode, since `delay` time has not been
	       * exceeded, schedule `callback` to execute `delay` ms after most
	       * recent execution.
	       *
	       * If `debounceMode` is true (at begin), schedule `clear` to execute
	       * after `delay` ms.
	       *
	       * If `debounceMode` is false (at end), schedule `callback` to
	       * execute after `delay` ms.
	       */
	      timeoutID = setTimeout(debounceMode ? clear : exec, debounceMode === undefined ? delay - elapsed : delay);
	    }
	  }

	  wrapper.cancel = cancel; // Return the wrapper function.

	  return wrapper;
	}

	/* eslint-disable no-undefined */
	/**
	 * Debounce execution of a function. Debouncing, unlike throttling,
	 * guarantees that a function is only executed a single time, either at the
	 * very beginning of a series of calls, or at the very end.
	 *
	 * @param  {Number}   delay         A zero-or-greater delay in milliseconds. For event callbacks, values around 100 or 250 (or even higher) are most useful.
	 * @param  {Boolean}  [atBegin]     Optional, defaults to false. If atBegin is false or unspecified, callback will only be executed `delay` milliseconds
	 *                                  after the last debounced-function call. If atBegin is true, callback will be executed only at the first debounced-function call.
	 *                                  (After the throttled-function has not been called for `delay` milliseconds, the internal counter is reset).
	 * @param  {Function} callback      A function to be executed after delay milliseconds. The `this` context and all arguments are passed through, as-is,
	 *                                  to `callback` when the debounced-function is executed.
	 *
	 * @return {Function} A new, debounced function.
	 */

	function debounce (delay, atBegin, callback) {
	  return callback === undefined ? throttle(delay, atBegin, false) : throttle(delay, callback, atBegin !== false);
	}

	/**
	 * Active popups.
	 *
	 * @var {array} activePopups
	 */

	var activePopups = [];
	/**
	 * Overlay z-index counter.
	 */

	var zIndexCounter = 99999;
	/**
	 * Hide already opened popups.
	 *
	 * @return {void}
	 */

	function hidePreviousPopup() {
	  var _iterator = _createForOfIteratorHelper(activePopups),
	      _step;

	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var popup = _step.value;

	      if (popup) {
	        popup.hide();
	        return;
	      }
	    }
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }
	}
	/**
	 * Show last active popup.
	 *
	 * @return {void}
	 */


	function showPreviousPopup() {
	  var _iterator2 = _createForOfIteratorHelper(activePopups.reverse()),
	      _step2;

	  try {
	    for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	      var popup = _step2.value;

	      if (popup) {
	        popup.open();
	        return;
	      }
	    }
	  } catch (err) {
	    _iterator2.e(err);
	  } finally {
	    _iterator2.f();
	  }
	}
	/**
	 * Kalium Popup.
	 */


	var Popup = /*#__PURE__*/function () {
	  /**
	   * Constructor.
	   *
	   * @param {string} title
	   * @param {string} content
	   * @param {object=} args
	   *
	   * @return {void}
	   */
	  function Popup(title, content, args) {
	    _classCallCheck(this, Popup);

	    // Display content only
	    if ('string' === typeof title && 'object' === _typeof(content) && !(content instanceof jQuery)) {
	      args = content;
	      content = title;
	      title = null;
	    } else if (title && !content) {
	      content = title;
	      title = null;
	    } // Random ID


	    this.id = 'popup-' + Math.random().toString(36).substr(2, 9); // Title and content

	    this.title = title;
	    this.content = content; // Args

	    this.args = jQuery.extend({
	      // Dismissable
	      dismissable: true,
	      // Dismiss by clicking overlay
	      dismissOverlay: true,
	      // Load content with iframe
	      iframe: false,
	      // Set auto-height for iframe (same-origin only)
	      iframeAutoHeight: false,
	      // Dimensions
	      width: 0,
	      height: 0,
	      minWidth: 0,
	      minHeight: 0,
	      maxWidth: 0,
	      maxHeight: 0,
	      // Hide active popups when opening current popup
	      hideOtherActive: true
	    }, args); // State vars

	    this._rendered = false;
	    this._isOpen = false;
	  }
	  /**
	   * Render popup.
	   *
	   * @return {void}
	   */


	  _createClass(Popup, [{
	    key: "render",
	    value: function render() {
	      // Overlay
	      this.$overlay = jQuery('<div class="kalium-popup__overlay"></div>').attr('id', this.id).css('z-index', zIndexCounter++); // Content

	      this.$content = jQuery('<div class="kalium-popup__content"></div>').attr('id', this.id).css('z-index', zIndexCounter++); // Title

	      if (this.title) {
	        this.$title = jQuery('<div class="kalium-popup__title"></div>').html(this.title).appendTo(this.$content);
	      } // Dismiss button


	      if (this.args.dismissable) {
	        this.$dismissButton = jQuery('<a href="#" class="kalium-popup__dismiss"><i class="dashicons dashicons-no-alt"></i></a>').appendTo(this.$content);
	      } // Content body


	      this.$contentBody = jQuery('<div class="kalium-popup__content-body"></div>').appendTo(this.$content); // Update size

	      this.updateSize(); // Insert content

	      this.$contentBody.append(this.getContent()); // Rendered state

	      this._rendered = true;
	    }
	    /**
	     * Setup events.
	     *
	     * @return {void}
	     */

	  }, {
	    key: "setupEvents",
	    value: function setupEvents() {
	      var _this = this;

	      // Dismiss overlay
	      this.$overlay.on('click', function (ev) {
	        ev.preventDefault();

	        if (_this.args.dismissOverlay && _this._isOpen) {
	          _this.close();
	        }
	      }); // Dismiss button

	      if (this.$dismissButton) {
	        this.$dismissButton.on('click', function (ev) {
	          ev.preventDefault();

	          if (_this.args.dismissable && _this._isOpen) {
	            _this.close();
	          }
	        });
	      } // Window events


	      if (window.addEventListener) {
	        var passiveEvent = detectPassiveEvents.hasSupport ? {
	          passive: true
	        } : false; // Resize popup container

	        this._resizeEvent = debounce(300, function () {
	          if (_this._isOpen) {
	            _this.updateSize();
	          }
	        });
	        window.addEventListener('resize', this._resizeEvent, passiveEvent); // Dismiss by escape key

	        this._dismissEvent = function (ev) {
	          if (27 === ev.which && _this._isOpen && _this.args.dismissOverlay) {
	            _this.close();
	          }
	        };

	        window.addEventListener('keyup', this._dismissEvent);
	      }
	    }
	    /**
	     * Render AJAX or IFrame content.
	     *
	     * @return {void}
	     */

	  }, {
	    key: "renderAjaxContent",
	    value: function renderAjaxContent() {
	      var self = this; // AJAX Content

	      this.$content.find('.kalium-popup__ajax-content').each(function (i, ajaxContent) {
	        var $ajaxContent = jQuery(ajaxContent),
	            url = $ajaxContent.data('url'); // Loading state

	        $ajaxContent.addClass('kalium-popup__ajax-content--loading'); // Fetch content

	        jQuery.get(url, function (content) {
	          $ajaxContent.html(content).removeClass('kalium-popup__ajax-content--loading').addClass('kalium-popup__ajax-content--loaded'); // Dispatch load event

	          jQuery(self).trigger('popup.load', [content, ajaxContent]); // Update size

	          self.updateSize();
	        });
	      });
	    }
	    /**
	     * Update popup size.
	     */

	  }, {
	    key: "updateSize",
	    value: function updateSize() {
	      var args = this.args,
	          dimensions = {
	        width: args.width,
	        height: args.height,
	        minWidth: args.minWidth,
	        minHeight: args.minHeight,
	        maxWidth: args.maxWidth,
	        maxHeight: args.maxHeight
	      };

	      for (var prop in dimensions) {
	        var size = dimensions[prop]; // Remove prop

	        this.$content.css(prop, ''); // Assign prop

	        if (size > 0) {
	          this.$content.css(prop, size);
	        }
	      } // Fit frame width with window viewpoint width


	      if (this.$content.outerWidth() > jQuery(window).width()) {
	        var newMaxWidth = jQuery(window).width(),
	            horizontalMargin = 50;
	        this.$content.css('max-width', newMaxWidth - horizontalMargin);
	        this.$content.css('min-width', newMaxWidth - horizontalMargin);
	      } // Fit frame height with window viewpoint height


	      if (this.$content.outerHeight() > jQuery(window).height()) {
	        var newMaxHeight = jQuery(window).height(),
	            verticalMargin = 100;
	        this.$content.css('max-height', newMaxHeight - verticalMargin);
	      }
	    }
	    /**
	     * Get popup content.
	     *
	     * @return {string}
	     */

	  }, {
	    key: "getContent",
	    value: function getContent() {
	      // Check if content is a URL
	      if ('string' === typeof this.content && this.content.match(/^https?:\/\/.+/)) {
	        // Auto height
	        this.$contentBody.addClass('kalium-popup__content-body--stretch-container'); // Use iframe

	        var self = this,
	            useIframe = self.args.iframe,
	            iframeAutoHeight = self.args.iframeAutoHeight;

	        if (useIframe) {
	          return jQuery('<iframe frameborder="0" hspace="0" allowtransparency="true" class="kalium-popup__iframe">This feature requires inline frames. You have iframes disabled or your browser does not support them.</iframe>').attr('src', this.content).on('load', function () {
	            var $iframe = jQuery(this);
	            $iframe.addClass('kalium-popup__iframe--loaded');

	            if (iframeAutoHeight) {
	              try {
	                var $contentDocument = jQuery(this.contentDocument),
	                    documentHeight = $contentDocument.height(),
	                    maxHeight = self.args.maxHeight;

	                if (maxHeight > 0 && documentHeight > maxHeight) {
	                  documentHeight = maxHeight;
	                }

	                $iframe.height(documentHeight);
	              } catch (e) {}
	            } // Dispatch load event


	            jQuery(self).trigger('load', [this]);
	          });
	        }

	        return jQuery('<div class="kalium-popup__ajax-content"></div>').data({
	          url: this.content
	        }).html('Loading&hellip;');
	      }

	      return this.content;
	    }
	    /**
	     * Open popup.
	     *
	     * @return {Popup}
	     */

	  }, {
	    key: "open",
	    value: function open() {
	      // If is already open, stop
	      if (this._isOpen) {
	        return this;
	      } // Render and show popup


	      if (false === this._rendered) {
	        // Render content
	        this.render(); // Setup events

	        this.setupEvents(); // Body container

	        var $body = jQuery(document.body); // Append to body

	        $body.append(this.$overlay);
	        $body.append(this.$content); // Render AJAX or iFrame elements

	        this.renderAjaxContent();
	      } else {
	        // Hidden class
	        var hiddenClass = 'kalium-popup--hidden'; // Show popup

	        this.$overlay.removeClass(hiddenClass);
	        this.$content.removeClass(hiddenClass);
	      } // Hide previously opened popups


	      if (this.args.hideOtherActive) {
	        hidePreviousPopup();
	      } // Add to active popups


	      activePopups.push(this); // Mark as open

	      this._isOpen = true; // Dispatch event on open

	      jQuery(this).trigger('popup.open');
	      return this;
	    }
	    /**
	     * Soft close popup without having to re render next time.
	     *
	     * @return {Popup}
	     */

	  }, {
	    key: "hide",
	    value: function hide() {
	      // If is already hidden, stop
	      if (!this._isOpen) {
	        return this;
	      } // Hidden class


	      var hiddenClass = 'kalium-popup--hidden'; // Hide popup

	      this.$overlay.addClass(hiddenClass);
	      this.$content.addClass(hiddenClass); // Mark as closed

	      this._isOpen = false; // Dispatch event on close

	      jQuery(this).trigger('popup.hide');
	      return this;
	    }
	    /**
	     * Close popup.
	     *
	     * @return {Popup}
	     */

	  }, {
	    key: "close",
	    value: function close() {
	      // Destroy containers
	      this.$overlay.remove();
	      this.$content.remove(); // Unset events

	      if (window.removeEventListener) {
	        window.removeEventListener('resize', this._resizeEvent);
	        window.removeEventListener('keyup', this._dismissEvent);
	      } // Set rendered property


	      this._rendered = false; // Mark as closed

	      this._isOpen = false; // Remove from active popups

	      for (var i in activePopups) {
	        if (this === activePopups[i]) {
	          delete activePopups[i];
	        }
	      } // Show previous opened popup


	      if (this.args.hideOtherActive) {
	        showPreviousPopup();
	      } // Dispatch event on close


	      jQuery(this).trigger('popup.close');
	      return this;
	    }
	  }]);

	  return Popup;
	}();
	/**
	 * Static method to open new Popup.
	 *
	 * @param {string} title
	 * @param {string} content
	 * @param {object=} args
	 *
	 * @return {Popup}
	 */


	Popup.open = function (title, content, args) {
	  return new Popup(title, content, args).open();
	}; // Export default

	/**
	 * Kalium error class, the implementation of WP_Error.
	 */
	var Kalium_Error = /*#__PURE__*/function () {
	  /**
	   * Constructor.
	   *
	   * @param {string|number|object} codeOrObject
	   * @param {string} message
	   * @param {string|object} data
	   */
	  function Kalium_Error() {
	    var codeOrObject = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
	    var message = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
	    var data = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';

	    _classCallCheck(this, Kalium_Error);

	    /**
	     * List of errors.
	     *
	     * @type {Object}
	     * @public
	     */
	    this.errors = {};
	    /**
	     * Error code data.
	     *
	     * @type {Object}
	     */

	    this.errorData = {}; // Initialize error

	    if (codeOrObject) {
	      this.add(codeOrObject, message, data);
	    }
	  }
	  /**
	   * Get error codes.
	   *
	   * @return {Array}
	   */


	  _createClass(Kalium_Error, [{
	    key: "getErrorCodes",
	    value: function getErrorCodes() {
	      if (this.hasErrors()) {
	        return Object.keys(this.errors);
	      }

	      return [];
	    }
	    /**
	     * Get first available error code.
	     *
	     * @return {string}
	     */

	  }, {
	    key: "getErrorCode",
	    value: function getErrorCode() {
	      var codes = this.getErrorCodes();

	      if (0 === codes.length) {
	        return '';
	      }

	      return codes[0];
	    }
	    /**
	     * Get error messages optionally filter by error code.
	     *
	     * @param {number|string} code
	     *
	     * @return {Array}
	     */

	  }, {
	    key: "getErrorMessages",
	    value: function getErrorMessages() {
	      var code = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
	      var errors = [];

	      for (var errorCode in this.errors) {
	        // Filter by error code
	        if (code && errorCode === "".concat(code)) {
	          var _iterator = _createForOfIteratorHelper(this.errors[errorCode]),
	              _step;

	          try {
	            for (_iterator.s(); !(_step = _iterator.n()).done;) {
	              var error = _step.value;
	              errors.push(error);
	            }
	          } catch (err) {
	            _iterator.e(err);
	          } finally {
	            _iterator.f();
	          }
	        } else if (!code) {
	          var _iterator2 = _createForOfIteratorHelper(this.errors[errorCode]),
	              _step2;

	          try {
	            for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	              var _error = _step2.value;
	              errors.push(_error);
	            }
	          } catch (err) {
	            _iterator2.e(err);
	          } finally {
	            _iterator2.f();
	          }
	        }
	      }

	      return errors;
	    }
	    /**
	     * Get single error message.
	     *
	     * @return {string}
	     */

	  }, {
	    key: "getErrorMessage",
	    value: function getErrorMessage() {
	      var code = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

	      if (!code) {
	        code = this.getErrorCode();
	      }

	      var messages = this.getErrorMessages(code);

	      if (0 === messages.length) {
	        return '';
	      }

	      return messages[0];
	    }
	    /**
	     * Get error data.
	     *
	     * @param {number|string} code
	     *
	     * @return {number|string|Object}
	     */

	  }, {
	    key: "getErrorData",
	    value: function getErrorData() {
	      var code = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

	      if (!code) {
	        code = this.getErrorCode();
	      }

	      if (this.errorData.hasOwnProperty(code)) {
	        return this.errorData[code];
	      }

	      return null;
	    }
	    /**
	     * Add error or append message for existing code.
	     *
	     * @param {string|number|object} codeOrObject
	     * @param {string} message
	     * @param {string|object} data
	     */

	  }, {
	    key: "add",
	    value: function add(codeOrObject) {
	      var _this = this;

	      var message = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
	      var data = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';

	      // Add from WP_Error
	      if (Kalium_Error.isWPError(codeOrObject)) {
	        var errors = codeOrObject.errors,
	            _data = codeOrObject.hasOwnProperty('error_data') ? codeOrObject.error_data : '';

	        for (var errorCode in errors) {
	          var errorMessage = errors[errorCode];

	          if (errorMessage instanceof Array) {
	            var _iterator3 = _createForOfIteratorHelper(errorMessage),
	                _step3;

	            try {
	              for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	                var _message = _step3.value;
	                this.add(errorCode, _message, _data);
	              }
	            } catch (err) {
	              _iterator3.e(err);
	            } finally {
	              _iterator3.f();
	            }
	          } else {
	            this.add(errorCode, errorMessage, _data);
	          }
	        }
	      } else if (Kalium_Error.isHTTPError(codeOrObject)) {
	        var response = codeOrObject.response ? codeOrObject.response : codeOrObject,
	            responseStatus = response.status,
	            responseMessage = response.statusText; // When response is an error

	        if (false === response.ok) {
	          this.add(responseStatus, responseMessage, response); // Response body add as message

	          if ('string' === typeof codeOrObject.body && codeOrObject.body) {
	            this.add(responseStatus, codeOrObject.body);
	          } else if (response.body instanceof ReadableStream && !response.body.locked) {
	            response.text().then(function (text) {
	              if (text) {
	                _this.add(responseStatus, text);
	              }
	            });
	          }
	        }
	      } else if (codeOrObject && ('string' === typeof codeOrObject || 'number' === typeof codeOrObject)) {
	        // Create error code array
	        if (!this.errors.hasOwnProperty(codeOrObject)) {
	          this.errors[codeOrObject] = [];
	        } // Append error


	        this.errors["".concat(codeOrObject)].push(message); // Add error data

	        this.addData(data, codeOrObject);
	      }
	    }
	    /**
	     * Add error data for given error code.
	     *
	     * @param {number|string|Object} data
	     * @param {number|string} code
	     */

	  }, {
	    key: "addData",
	    value: function addData(data) {
	      var code = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';

	      if (!data) {
	        return;
	      }

	      if (!code) {
	        code = this.getErrorCode();
	      }

	      if ('object' === _typeof(data)) {
	        for (var errorCode in data) {
	          this.errorData[errorCode] = data[errorCode];
	        }
	      } else {
	        this.errorData[code] = data;
	      }
	    }
	    /**
	     * Check if there are errors.
	     *
	     * @return {boolean}
	     */

	  }, {
	    key: "hasErrors",
	    value: function hasErrors() {
	      return Object.keys(this.errors).length > 0;
	    }
	    /**
	     * Wrap error messages in HTML tags.
	     *
	     * @param {number|string} code
	     * @param {Object} args
	     *
	     * @return {string}
	     */

	  }, {
	    key: "wrapErrors",
	    value: function wrapErrors() {
	      var code = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
	      var args = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	      var str = '',
	          errorMessages = this.getErrorMessages(code); // Args extend

	      args = _objectSpread2({
	        tagName: 'div',
	        className: 'error-entry'
	      }, args);

	      var _iterator4 = _createForOfIteratorHelper(errorMessages),
	          _step4;

	      try {
	        for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	          var message = _step4.value;
	          str += "<".concat(args.tagName, " class=\"").concat(args.className, "\">").concat(message, "</").concat(args.tagName, ">\n");
	        }
	      } catch (err) {
	        _iterator4.e(err);
	      } finally {
	        _iterator4.f();
	      }

	      return str.trim();
	    }
	  }]);

	  return Kalium_Error;
	}();
	/**
	 * Check if given argument is WP_Error
	 *
	 * @param thing
	 *
	 * @return {boolean}
	 */


	Kalium_Error.isWPError = function (thing) {
	  return 'object' === _typeof(thing) && thing.hasOwnProperty('errors') && 'object' === _typeof(thing.errors);
	};
	/**
	 * Check if given argument is HTTP response error.
	 *
	 * @param thing
	 *
	 * @return {boolean}
	 */


	Kalium_Error.isHTTPError = function (thing) {
	  return 'object' === _typeof(thing) && (thing instanceof Response || thing.response instanceof Response) && thing.status >= 300;
	}; // Export default

	/**
	 * Content import actions.
	 *
	 * @type string
	 */

	var CONTENT_IMPORT_ACTION_DOWNLOAD = 'do_download';
	var CONTENT_IMPORT_ACTION_BACKUP = 'do_backup';
	var CONTENT_IMPORT_ACTION_IMPORT = 'do_import';
	var CONTENT_IMPORT_ACTION_COMPLETE = 'do_complete';
	var CONTENT_IMPORT_ACTION_REMOVE = 'do_remove';
	/**
	 * Parse JSON from response DOM element.
	 *
	 * @param {string} contents
	 * @param {string} selector
	 *
	 * @return {object|null}
	 */

	function responseParseJSON(contents, selector) {
	  // Create element to retrieve JSON response from ${selector}
	  var testElement = document.createElement('div');
	  testElement.innerHTML = contents; // TGMPA response

	  var contentElement = testElement.querySelector(selector),
	      jsonContent = contentElement ? contentElement.innerHTML : ''; // Remove created element from memory

	  testElement.remove();
	  testElement = null;

	  try {
	    return JSON.parse(jsonContent);
	  } catch (e) {}

	  return null;
	}
	/**
	 * Show error popup.
	 *
	 * @param {Kalium_Error} errors
	 * @param {array} buttons
	 * @param {object} args
	 *
	 * @return {Popup}
	 */


	function showErrorPopup(errors) {
	  var buttons = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
	  var args = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
	  // Defaults
	  args = _objectSpread2({
	    title: 'Error'
	  }, args); // Popup content

	  var $content = jQuery('<div class="kalium-demos__popup-errors"></div>'); // Errors list

	  $content.append(errors.wrapErrors('', {
	    className: 'kalium-demos__popup-error'
	  })); // Buttons

	  if (buttons.length > 0) {
	    var $buttons = jQuery('<div class="kalium-demos__popup-errors-buttons"></div>');

	    var _iterator = _createForOfIteratorHelper(buttons),
	        _step;

	    try {
	      var _loop = function _loop() {
	        var button = _step.value;
	        button = _objectSpread2({
	          title: '',
	          class: 'button',
	          link: '#',
	          click: null
	        }, button); // Button

	        var $button = jQuery('<a></a>').attr({
	          href: button.link,
	          class: button.class
	        }).html(button.title); // Click event

	        if ('function' === typeof button.click) {
	          $button.on('click', function (ev) {
	            ev.preventDefault();
	            button.click.call($button, popup);
	          });
	        } // Add button


	        $buttons.append($button);
	      };

	      for (_iterator.s(); !(_step = _iterator.n()).done;) {
	        _loop();
	      } // Append buttons to errors container

	    } catch (err) {
	      _iterator.e(err);
	    } finally {
	      _iterator.f();
	    }

	    $content.append($buttons);
	  } // Popup instance


	  var popup = new Popup(args.title, $content, {
	    dismissable: false,
	    dismissOverlay: false,
	    minWidth: 600,
	    hideOtherActive: false
	  }); // Open popup

	  popup.open();
	  return popup;
	}
	/**
	 * Sanitize HTML.
	 *
	 * @param {string} str
	 *
	 * @return {string}
	 */


	function sanitizeHTML(str) {
	  var temp = document.createElement('div');
	  temp.textContent = str;
	  return temp.innerHTML;
	}
	/**
	 * Log to console.
	 *
	 * @return void
	 */


	function debugLog() {
	  var _console;

	  (_console = console).log.apply(_console, arguments);
	}
	/**
	 * Kalium Import Task class.
	 *
	 * @class Kalium_Import_Task
	 */


	var Kalium_Import_Task = /*#__PURE__*/function () {
	  /**
	   * Constructor.
	   *
	   * @param {object} taskObj
	   */
	  function Kalium_Import_Task(taskObj) {
	    _classCallCheck(this, Kalium_Import_Task);

	    // Task type
	    this.type = taskObj.type; // Task args

	    this.args = taskObj.args; // Task status

	    this.isCompleted = taskObj.completed;
	    /**
	     * Errors.
	     *
	     * @type Kalium_Error
	     */

	    this.errors = new Kalium_Error();
	  }
	  /**
	   * Get task type.
	   *
	   * @return {string}
	   */


	  _createClass(Kalium_Import_Task, [{
	    key: "getType",
	    value: function getType() {
	      return this.type;
	    }
	    /**
	     * Get task args.
	     *
	     * @return {object}
	     */

	  }, {
	    key: "getArgs",
	    value: function getArgs() {
	      return this.args;
	    }
	    /**
	     * Get single argument.
	     *
	     * @param {string} name
	     *
	     * @return {string|object|null}
	     */

	  }, {
	    key: "getArg",
	    value: function getArg(name) {
	      if (this.args.hasOwnProperty(name)) {
	        return this.args[name];
	      }

	      return null;
	    }
	    /**
	     * Check if task is completed.
	     *
	     * @param {boolean|null} newStatus
	     *
	     * @return {boolean}
	     */

	  }, {
	    key: "completed",
	    value: function completed() {
	      var newStatus = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;

	      // Setter
	      if ('boolean' === typeof newStatus) {
	        this.isCompleted = newStatus;
	      }

	      return this.isCompleted;
	    }
	    /**
	     * Get error object.
	     *
	     * @return {Kalium_Error}
	     */

	  }, {
	    key: "getErrors",
	    value: function getErrors() {
	      return this.errors;
	    }
	    /**
	     * Install plugin task.
	     *
	     * @param {Kalium_Import} importInstance
	     * @param {function} parentResolve
	     * @param {function} parentReject
	     *
	     * @return {void}
	     */

	  }, {
	    key: "installPlugin",
	    value: function installPlugin(importInstance, parentResolve, parentReject) {
	      var _this = this;

	      // Vars
	      var slug = this.getArg('slug'),
	          installed = this.getArg('installed'),
	          $pluginEntry = importInstance.$requiredPlugins.filter("[data-plugin-slug=\"".concat(slug, "\"]")),
	          $pluginStatus = $pluginEntry.find('.kalium-demos__content-pack-view-required-plugins-status span'); // Set status class

	      $pluginStatus.addClass('installing'); // Activating plugin

	      if (installed) {
	        $pluginStatus.html('Activating&hellip;');
	      } else {
	        $pluginStatus.html('Installing&hellip;');
	      } // Clear errors


	      this.errors = new Kalium_Error(); // Make API call

	      importInstance.api(this.getType(), this.getArgs()).then(function (response) {
	        // Check TGMPA response status
	        var tgmpaResponse = responseParseJSON(response.body, '.kalium-tgmpa-ajax-response'),
	            success = tgmpaResponse && tgmpaResponse.hasOwnProperty('success') ? tgmpaResponse.success : false; // Task is completed

	        _this.completed(true); // Remove status class


	        $pluginStatus.removeClass('install installing activate'); // Plugin action succeeded

	        if (success) {
	          // Set new status
	          $pluginStatus.addClass('active').html('Active'); // Successful request

	          parentResolve(tgmpaResponse);
	        } // Plugin action failed
	        else {
	            // Set failed status
	            $pluginStatus.addClass('failed').html('Failed'); // Set task error

	            _this.errors.add('plugin_install_failed', 'Plugin install or activate action failed!'); // Unsuccessful request


	            parentReject({
	              type: 'plugin-install-fail',
	              message: _this.errors.getErrorMessage()
	            });
	          }
	      }).catch(function (response) {
	        // Remove status class
	        $pluginStatus.removeClass('install installing activate'); // Set failed status

	        $pluginStatus.addClass('failed').html('Failed'); // Task is completed

	        _this.completed(true); // Set task error


	        _this.errors.add(response); // Unsuccessful request


	        parentReject({
	          type: 'plugin-install-fail',
	          message: _this.errors.getErrorMessage()
	        });
	      });
	    }
	    /**
	     * Import content task.
	     *
	     * @param {Kalium_Import} importInstance
	     * @param {function} parentResolve
	     * @param {function} parentReject
	     *
	     * @return {void}
	     */

	  }, {
	    key: "importContent",
	    value: function importContent(importInstance, parentResolve, parentReject) {
	      var _this2 = this;

	      // Vars
	      var importId = this.getArg('import_id'),
	          importName = this.getArg('import_name'),
	          uninstall = this.getArg('uninstall'),
	          importField = importInstance.getContentImportField(importId),
	          label = importField.label,
	          apiArgs = {
	        importId: importId,
	        checked: importField.checked,
	        args: JSON.stringify(importField.argsFields)
	      }; // Set progress status

	      if (uninstall) {
	        importInstance.setProgressStatus("Removing ".concat(label, "..."));
	      } else {
	        importInstance.setProgressStatus("Importing ".concat(label, "..."));
	      } // Clear task errors


	      this.errors = new Kalium_Error();
	      /**
	       * Show HTTP error popup.
	       *
	       * @param {object} response
	       * @param {array} buttons
	       *
	       * @return void
	       */

	      var showHttpErrorPopup = function showHttpErrorPopup(response) {
	        var buttons = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
	        // Errors and response body content
	        var responseBody = sanitizeHTML(response.body),
	            error = new Kalium_Error(); // Include HTTP error message

	        if (Kalium_Error.isHTTPError(response)) {
	          error.add("http_error_".concat(response.status), "Status code: ".concat(response.status, " ").concat(response.statusText));
	        } else {
	          error.add('unknown_error', "An unknown error occurred (error code ".concat(response.status, ")"));
	        } // Add response body to error instance


	        if (responseBody) {
	          error.add(error.getErrorCode(), "<pre class=\"kalium-demos__popup-errors-pre\">".concat(responseBody, "</pre>"));
	        } // Add error to task


	        _this2.errors.add(error); // Show error popup


	        showErrorPopup(error, buttons, {
	          title: "Error - ".concat(importName)
	        });
	      };
	      /**
	       * Handle successful request.
	       *
	       * @param {object} importAction
	       * @param {object} response
	       *
	       * @return {Promise}
	       */


	      var handleSuccessfulRequest = function handleSuccessfulRequest(importAction, response) {
	        return new Promise(function (resolve, reject) {
	          // Vars
	          var result = responseParseJSON(response.body, '.kalium-demo-content-import-response'),
	              buttons = {
	            registerTheme: {
	              title: 'Register theme',
	              link: 'admin.php?page=kalium&tab=theme-registration',
	              class: 'button button-primary'
	            },
	            continue: {
	              title: 'Continue',
	              class: 'button button-primary',
	              click: function click(popup) {
	                popup.close(); // Resolve, continue

	                resolve();
	              }
	            },
	            retry: {
	              title: 'Retry',
	              class: 'button',
	              click: function click(popup) {
	                popup.close(); // Retry by executing the task again

	                _this2.importContent(importInstance, parentResolve, parentReject);
	              }
	            },
	            close: {
	              title: 'Close',
	              click: function click(popup) {
	                popup.close(); // Abort process

	                parentReject({
	                  abort: true
	                });
	              }
	            },
	            closePopup: {
	              title: 'Close',
	              click: function click(popup) {
	                popup.close();
	                importInstance.close(); // Abort process

	                parentReject({
	                  abort: true
	                });
	              }
	            }
	          }; // Valid result

	          if (result) {
	            // Successful task execution
	            if (result.success) {
	              // Resolve
	              resolve();
	            } else {
	              // On error
	              if (Kalium_Error.isWPError(result)) {
	                // Vars
	                var error = new Kalium_Error(result),
	                    errorTitle = "Error - ".concat(importName),
	                    errorData = error.getErrorData(),
	                    errorButtons = [buttons.continue, buttons.retry, buttons.close]; // Add error to task

	                _this2.errors.add(error); // Silent error, pass


	                if (errorData && errorData.silent) {
	                  resolve({
	                    silent: true
	                  });
	                  return;
	                } // Custom popup buttons


	                if (errorData && errorData.popupButtons) {
	                  errorButtons = [];

	                  var _iterator2 = _createForOfIteratorHelper(errorData.popupButtons),
	                      _step2;

	                  try {
	                    for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	                      var button = _step2.value;

	                      if (buttons.hasOwnProperty(button)) {
	                        errorButtons.push(buttons[button]);
	                      }
	                    }
	                  } catch (err) {
	                    _iterator2.e(err);
	                  } finally {
	                    _iterator2.f();
	                  }
	                } // Show error popup


	                showErrorPopup(error, errorButtons, {
	                  title: errorTitle
	                });
	              } else {
	                // Undefined error
	                var _error = new Kalium_Error('unknown_error', 'An unknown error occurred'),
	                    rawResponse = sanitizeHTML(JSON.stringify(result)); // Add error to task


	                _this2.errors.add(_error); // Insert result object


	                _error.add(_error.getErrorCode(), "<pre class=\"kalium-demos__popup-errors-pre\">".concat(rawResponse, "</pre>")); // Show error on popup


	                showErrorPopup(_error, [buttons.continue, buttons.close], {
	                  title: "Error - ".concat(importName)
	                });
	              }
	            }
	          } else {
	            // Unknown error
	            showHttpErrorPopup(response, [buttons.continue, buttons.retry, buttons.close]);
	          }
	        });
	      };
	      /**
	       * Failed request handler.
	       *
	       * @param {object} importAction
	       * @param {object} err
	       *
	       * @return {Promise}
	       */


	      var handleFailedRequest = function handleFailedRequest(importAction, err) {
	        return new Promise(function (resolve, reject) {
	          // Response body
	          var responseBody = err && err.body ? err.body : '',
	              result = responseParseJSON(responseBody, '.kalium-demo-content-import-response'),
	              buttons = {
	            continue: {
	              title: 'Continue',
	              class: 'button button-primary',
	              click: function click(popup) {
	                popup.close(); // Resolve, continue

	                resolve();
	              }
	            },
	            close: {
	              title: 'Close',
	              click: function click(popup) {
	                popup.close(); // Abort process

	                parentReject({
	                  abort: true
	                });
	              }
	            }
	          }; // If valid result is parsed from the error response

	          if (result) {
	            // Use error handler in handleSuccessfulRequest() function
	            handleSuccessfulRequest(importAction, err).then(resolve).catch(reject);
	            return;
	          } // Abort process


	          if (err && err.abort) {
	            parentReject(err);
	            return;
	          } // Show error popup


	          showHttpErrorPopup(err, [buttons.continue, buttons.close]);
	        });
	      }; // Uninstall


	      if (uninstall) {
	        /**
	         * Do remove
	         *
	         * CONTENT_IMPORT_ACTION_REMOVE
	         */
	        var removePromise = importInstance.api(this.getType(), _objectSpread2({
	          importAction: CONTENT_IMPORT_ACTION_REMOVE
	        }, apiArgs)).then(function (response) {
	          return handleSuccessfulRequest(CONTENT_IMPORT_ACTION_REMOVE, response);
	        }).catch(function (err) {
	          return handleFailedRequest(CONTENT_IMPORT_ACTION_REMOVE, err);
	        });
	        /**
	         * Remove finished for this content type
	         */

	        removePromise.finally(function () {
	          // Mark task as completed
	          _this2.completed(true); // Resolve


	          parentResolve();
	        });
	      } else {
	        /**
	         * Do download
	         *
	         * CONTENT_IMPORT_ACTION_DOWNLOAD
	         */
	        var downloadPromise = importInstance.api(this.getType(), _objectSpread2({
	          importAction: CONTENT_IMPORT_ACTION_DOWNLOAD
	        }, apiArgs)).then(function (response) {
	          return handleSuccessfulRequest(CONTENT_IMPORT_ACTION_DOWNLOAD, response);
	        }).catch(function (err) {
	          return handleFailedRequest(CONTENT_IMPORT_ACTION_DOWNLOAD, err);
	        });
	        /**
	         * Do backup
	         *
	         * CONTENT_IMPORT_ACTION_BACKUP
	         */

	        var backupPromise = downloadPromise.then(function () {
	          return importInstance.api(_this2.getType(), _objectSpread2({
	            importAction: CONTENT_IMPORT_ACTION_BACKUP
	          }, apiArgs)).then(function (response) {
	            return handleSuccessfulRequest(CONTENT_IMPORT_ACTION_BACKUP, response);
	          }).catch(function (err) {
	            return handleFailedRequest(CONTENT_IMPORT_ACTION_BACKUP, err);
	          });
	        });
	        /**
	         * Do import
	         *
	         * CONTENT_IMPORT_ACTION_IMPORT
	         */

	        var importPromise = backupPromise.then(function () {
	          return importInstance.api(_this2.getType(), _objectSpread2({
	            importAction: CONTENT_IMPORT_ACTION_IMPORT
	          }, apiArgs)).then(function (response) {
	            return handleSuccessfulRequest(CONTENT_IMPORT_ACTION_IMPORT, response);
	          }).catch(function (err) {
	            return handleFailedRequest(CONTENT_IMPORT_ACTION_IMPORT, err);
	          });
	        });
	        /**
	         * Do complete
	         *
	         * CONTENT_IMPORT_ACTION_COMPLETE
	         */

	        var completePromise = importPromise.then(function () {
	          return importInstance.api(_this2.getType(), _objectSpread2({
	            importAction: CONTENT_IMPORT_ACTION_COMPLETE
	          }, apiArgs)).then(function (response) {
	            return handleSuccessfulRequest(CONTENT_IMPORT_ACTION_COMPLETE, response);
	          }).catch(function (err) {
	            return handleFailedRequest(CONTENT_IMPORT_ACTION_COMPLETE, err);
	          });
	        });
	        /**
	         * Import finished for this content type
	         */

	        completePromise.finally(function () {
	          // Mark task as completed
	          _this2.completed(true); // Resolve


	          parentResolve();
	        });
	      }
	    }
	    /**
	     * Execute task.
	     *
	     * @param {Kalium_Import} importInstance
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "execute",
	    value: function execute(importInstance) {
	      var _this3 = this;

	      return new Promise(function (resolve, reject) {
	        // Plugin install task
	        if ('plugin-install' === _this3.getType()) {
	          _this3.installPlugin(importInstance, resolve, reject);
	        } // Content import task
	        else if ('content-import' === _this3.getType()) {
	            _this3.importContent(importInstance, resolve, reject);
	          }
	      });
	    }
	  }]);

	  return Kalium_Import_Task;
	}();
	/**
	 * Task runner class.
	 *
	 * @class Kalium_Import_Task_Runner
	 */


	var Kalium_Import_Task_Runner = /*#__PURE__*/function () {
	  /**
	   * Constructor.
	   *
	   * @param {Kalium_Import} importInstance
	   */
	  function Kalium_Import_Task_Runner(importInstance) {
	    _classCallCheck(this, Kalium_Import_Task_Runner);

	    /**
	     * @property {Kalium_Import} tasksList
	     */
	    this.importInstance = importInstance;
	  }
	  /**
	   * Get tasks (optionally filter by type).
	   *
	   * @param {string=} taskType
	   *
	   * @return {Kalium_Import_Task[]}
	   */


	  _createClass(Kalium_Import_Task_Runner, [{
	    key: "getTasks",
	    value: function getTasks(taskType) {
	      return this.importInstance.tasksList.filter(function (task) {
	        return !taskType || task.getType() === taskType;
	      });
	    }
	    /**
	     * Run tasks (optionally by type).
	     *
	     * @param {string=} taskType
	     * @param {function=} taskCompleteCallback
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "runTasks",
	    value: function runTasks(taskType) {
	      var _this4 = this;

	      var taskCompleteCallback = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	      return new Promise(function (resolve, reject) {
	        // Tasks to run (completed only)
	        var tasks = _this4.getTasks(taskType),
	            totalTime = [];
	        /**
	         * Task runner recursive.
	         *
	         * @param {Kalium_Import_Task[]} tasks
	         */


	        var taskRunner = function taskRunner(tasks) {
	          var task = tasks.shift(),
	              startTime = performance.now(); // Update progress bar

	          _this4.updateProgressBar(); // All tasks completed


	          if (!task) {
	            // Total execution time
	            totalTime = totalTime.length > 0 ? totalTime.reduce(function (a, b) {
	              return a + b;
	            }) : 0;
	            debugLog('***', 'Total time:', +totalTime.toFixed(1), 's', '***'); // Resolve

	            resolve();
	          } // Skip completed task
	          else if (task.completed()) {
	              taskRunner(tasks);
	            } // Execute task
	            else {
	                task.execute(_this4.importInstance) // Task complete
	                .then(function () {
	                  // Callback for each completed task
	                  if (taskCompleteCallback instanceof Function) {
	                    taskCompleteCallback.call(_this4, task);
	                  } // Calculate execution time (in seconds)


	                  var executionTime = (performance.now() - startTime) / 1000;
	                  totalTime.push(executionTime); // Report task time

	                  var taskDescription = task.getType();

	                  if ('plugin-install' === taskDescription) {
	                    taskDescription += ': ' + task.getArg('name');
	                  } else if ('content-import' === taskDescription) {
	                    taskDescription += ': ' + task.getArg('import_name');
	                  } // Execution time debug


	                  debugLog(taskDescription, +executionTime.toFixed(1), 's'); // Run next task

	                  taskRunner(tasks);
	                }) // Task failed
	                .catch(function (err) {
	                  // Close import instance
	                  if (err && err.abort) {
	                    reject({
	                      errCode: 0,
	                      reason: 'Aborted by user.'
	                    });
	                  } // Continue running tasks
	                  else {
	                      taskRunner(tasks);
	                    }
	                });
	              }
	        }; // Start task runner


	        taskRunner(tasks);
	      });
	    }
	    /**
	     * Get number of completed tasks.
	     *
	     * @param {string=} taskType
	     *
	     * @return {number}
	     */

	  }, {
	    key: "getCompletedTasksNumber",
	    value: function getCompletedTasksNumber(taskType) {
	      var completed = 0;

	      var _iterator3 = _createForOfIteratorHelper(this.getTasks(taskType)),
	          _step3;

	      try {
	        for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	          var task = _step3.value;

	          if (task.completed()) {
	            completed++;
	          }
	        }
	      } catch (err) {
	        _iterator3.e(err);
	      } finally {
	        _iterator3.f();
	      }

	      return completed;
	    }
	    /**
	     * Update progress bar.
	     *
	     * @return {void}
	     */

	  }, {
	    key: "updateProgressBar",
	    value: function updateProgressBar() {
	      var tasksByType = {},
	          totalPoints = 0,
	          completedPoints = 0,
	          taskWeights = {
	        'plugin-install': 1,
	        'content-import': 3
	      };

	      var _iterator4 = _createForOfIteratorHelper(this.importInstance.tasksList),
	          _step4;

	      try {
	        for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	          var _task = _step4.value;

	          var type = _task.getType();

	          if (!tasksByType[type]) {
	            tasksByType[type] = {
	              weight: 1,
	              tasks: []
	            }; // Set weight

	            if (taskWeights.hasOwnProperty(type)) {
	              tasksByType[type].weight = taskWeights[type];
	            }
	          } // Add task to the group


	          tasksByType[type].tasks.push(_task); // Register total points

	          totalPoints += tasksByType[type].weight;
	        } // Count completed tasks

	      } catch (err) {
	        _iterator4.e(err);
	      } finally {
	        _iterator4.f();
	      }

	      for (var taskType in tasksByType) {
	        var _iterator5 = _createForOfIteratorHelper(tasksByType[taskType].tasks),
	            _step5;

	        try {
	          for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
	            var task = _step5.value;

	            if (task.completed()) {
	              completedPoints += tasksByType[taskType].weight;
	            }
	          }
	        } catch (err) {
	          _iterator5.e(err);
	        } finally {
	          _iterator5.f();
	        }
	      } // Update progress


	      this.importInstance.setProgress(completedPoints / totalPoints * 100);
	    }
	  }]);

	  return Kalium_Import_Task_Runner;
	}(); // Export Kalium_Import_Task class

	/*
	 * anime.js v3.1.0
	 * (c) 2019 Julian Garnier
	 * Released under the MIT license
	 * animejs.com
	 */

	var defaultInstanceSettings = {
	  update: null,
	  begin: null,
	  loopBegin: null,
	  changeBegin: null,
	  change: null,
	  changeComplete: null,
	  loopComplete: null,
	  complete: null,
	  loop: 1,
	  direction: 'normal',
	  autoplay: true,
	  timelineOffset: 0
	};
	var defaultTweenSettings = {
	  duration: 1000,
	  delay: 0,
	  endDelay: 0,
	  easing: 'easeOutElastic(1, .5)',
	  round: 0
	};
	var validTransforms = ['translateX', 'translateY', 'translateZ', 'rotate', 'rotateX', 'rotateY', 'rotateZ', 'scale', 'scaleX', 'scaleY', 'scaleZ', 'skew', 'skewX', 'skewY', 'perspective']; // Caching

	var cache = {
	  CSS: {},
	  springs: {}
	}; // Utils

	function minMax(val, min, max) {
	  return Math.min(Math.max(val, min), max);
	}

	function stringContains(str, text) {
	  return str.indexOf(text) > -1;
	}

	function applyArguments(func, args) {
	  return func.apply(null, args);
	}

	var is = {
	  arr: function arr(a) {
	    return Array.isArray(a);
	  },
	  obj: function obj(a) {
	    return stringContains(Object.prototype.toString.call(a), 'Object');
	  },
	  pth: function pth(a) {
	    return is.obj(a) && a.hasOwnProperty('totalLength');
	  },
	  svg: function svg(a) {
	    return a instanceof SVGElement;
	  },
	  inp: function inp(a) {
	    return a instanceof HTMLInputElement;
	  },
	  dom: function dom(a) {
	    return a.nodeType || is.svg(a);
	  },
	  str: function str(a) {
	    return typeof a === 'string';
	  },
	  fnc: function fnc(a) {
	    return typeof a === 'function';
	  },
	  und: function und(a) {
	    return typeof a === 'undefined';
	  },
	  hex: function hex(a) {
	    return /(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i.test(a);
	  },
	  rgb: function rgb(a) {
	    return /^rgb/.test(a);
	  },
	  hsl: function hsl(a) {
	    return /^hsl/.test(a);
	  },
	  col: function col(a) {
	    return is.hex(a) || is.rgb(a) || is.hsl(a);
	  },
	  key: function key(a) {
	    return !defaultInstanceSettings.hasOwnProperty(a) && !defaultTweenSettings.hasOwnProperty(a) && a !== 'targets' && a !== 'keyframes';
	  }
	}; // Easings

	function parseEasingParameters(string) {
	  var match = /\(([^)]+)\)/.exec(string);
	  return match ? match[1].split(',').map(function (p) {
	    return parseFloat(p);
	  }) : [];
	} // Spring solver inspired by Webkit Copyright © 2016 Apple Inc. All rights reserved. https://webkit.org/demos/spring/spring.js


	function spring(string, duration) {
	  var params = parseEasingParameters(string);
	  var mass = minMax(is.und(params[0]) ? 1 : params[0], .1, 100);
	  var stiffness = minMax(is.und(params[1]) ? 100 : params[1], .1, 100);
	  var damping = minMax(is.und(params[2]) ? 10 : params[2], .1, 100);
	  var velocity = minMax(is.und(params[3]) ? 0 : params[3], .1, 100);
	  var w0 = Math.sqrt(stiffness / mass);
	  var zeta = damping / (2 * Math.sqrt(stiffness * mass));
	  var wd = zeta < 1 ? w0 * Math.sqrt(1 - zeta * zeta) : 0;
	  var a = 1;
	  var b = zeta < 1 ? (zeta * w0 + -velocity) / wd : -velocity + w0;

	  function solver(t) {
	    var progress = duration ? duration * t / 1000 : t;

	    if (zeta < 1) {
	      progress = Math.exp(-progress * zeta * w0) * (a * Math.cos(wd * progress) + b * Math.sin(wd * progress));
	    } else {
	      progress = (a + b * progress) * Math.exp(-progress * w0);
	    }

	    if (t === 0 || t === 1) {
	      return t;
	    }

	    return 1 - progress;
	  }

	  function getDuration() {
	    var cached = cache.springs[string];

	    if (cached) {
	      return cached;
	    }

	    var frame = 1 / 6;
	    var elapsed = 0;
	    var rest = 0;

	    while (true) {
	      elapsed += frame;

	      if (solver(elapsed) === 1) {
	        rest++;

	        if (rest >= 16) {
	          break;
	        }
	      } else {
	        rest = 0;
	      }
	    }

	    var duration = elapsed * frame * 1000;
	    cache.springs[string] = duration;
	    return duration;
	  }

	  return duration ? solver : getDuration;
	} // Basic steps easing implementation https://developer.mozilla.org/fr/docs/Web/CSS/transition-timing-function


	function steps(steps) {
	  if (steps === void 0) steps = 10;
	  return function (t) {
	    return Math.round(t * steps) * (1 / steps);
	  };
	} // BezierEasing https://github.com/gre/bezier-easing


	var bezier = function () {
	  var kSplineTableSize = 11;
	  var kSampleStepSize = 1.0 / (kSplineTableSize - 1.0);

	  function A(aA1, aA2) {
	    return 1.0 - 3.0 * aA2 + 3.0 * aA1;
	  }

	  function B(aA1, aA2) {
	    return 3.0 * aA2 - 6.0 * aA1;
	  }

	  function C(aA1) {
	    return 3.0 * aA1;
	  }

	  function calcBezier(aT, aA1, aA2) {
	    return ((A(aA1, aA2) * aT + B(aA1, aA2)) * aT + C(aA1)) * aT;
	  }

	  function getSlope(aT, aA1, aA2) {
	    return 3.0 * A(aA1, aA2) * aT * aT + 2.0 * B(aA1, aA2) * aT + C(aA1);
	  }

	  function binarySubdivide(aX, aA, aB, mX1, mX2) {
	    var currentX,
	        currentT,
	        i = 0;

	    do {
	      currentT = aA + (aB - aA) / 2.0;
	      currentX = calcBezier(currentT, mX1, mX2) - aX;

	      if (currentX > 0.0) {
	        aB = currentT;
	      } else {
	        aA = currentT;
	      }
	    } while (Math.abs(currentX) > 0.0000001 && ++i < 10);

	    return currentT;
	  }

	  function newtonRaphsonIterate(aX, aGuessT, mX1, mX2) {
	    for (var i = 0; i < 4; ++i) {
	      var currentSlope = getSlope(aGuessT, mX1, mX2);

	      if (currentSlope === 0.0) {
	        return aGuessT;
	      }

	      var currentX = calcBezier(aGuessT, mX1, mX2) - aX;
	      aGuessT -= currentX / currentSlope;
	    }

	    return aGuessT;
	  }

	  function bezier(mX1, mY1, mX2, mY2) {
	    if (!(0 <= mX1 && mX1 <= 1 && 0 <= mX2 && mX2 <= 1)) {
	      return;
	    }

	    var sampleValues = new Float32Array(kSplineTableSize);

	    if (mX1 !== mY1 || mX2 !== mY2) {
	      for (var i = 0; i < kSplineTableSize; ++i) {
	        sampleValues[i] = calcBezier(i * kSampleStepSize, mX1, mX2);
	      }
	    }

	    function getTForX(aX) {
	      var intervalStart = 0;
	      var currentSample = 1;
	      var lastSample = kSplineTableSize - 1;

	      for (; currentSample !== lastSample && sampleValues[currentSample] <= aX; ++currentSample) {
	        intervalStart += kSampleStepSize;
	      }

	      --currentSample;
	      var dist = (aX - sampleValues[currentSample]) / (sampleValues[currentSample + 1] - sampleValues[currentSample]);
	      var guessForT = intervalStart + dist * kSampleStepSize;
	      var initialSlope = getSlope(guessForT, mX1, mX2);

	      if (initialSlope >= 0.001) {
	        return newtonRaphsonIterate(aX, guessForT, mX1, mX2);
	      } else if (initialSlope === 0.0) {
	        return guessForT;
	      } else {
	        return binarySubdivide(aX, intervalStart, intervalStart + kSampleStepSize, mX1, mX2);
	      }
	    }

	    return function (x) {
	      if (mX1 === mY1 && mX2 === mY2) {
	        return x;
	      }

	      if (x === 0 || x === 1) {
	        return x;
	      }

	      return calcBezier(getTForX(x), mY1, mY2);
	    };
	  }

	  return bezier;
	}();

	var penner = function () {
	  // Based on jQuery UI's implemenation of easing equations from Robert Penner (http://www.robertpenner.com/easing)
	  var eases = {
	    linear: function linear() {
	      return function (t) {
	        return t;
	      };
	    }
	  };
	  var functionEasings = {
	    Sine: function Sine() {
	      return function (t) {
	        return 1 - Math.cos(t * Math.PI / 2);
	      };
	    },
	    Circ: function Circ() {
	      return function (t) {
	        return 1 - Math.sqrt(1 - t * t);
	      };
	    },
	    Back: function Back() {
	      return function (t) {
	        return t * t * (3 * t - 2);
	      };
	    },
	    Bounce: function Bounce() {
	      return function (t) {
	        var pow2,
	            b = 4;

	        while (t < ((pow2 = Math.pow(2, --b)) - 1) / 11) {}

	        return 1 / Math.pow(4, 3 - b) - 7.5625 * Math.pow((pow2 * 3 - 2) / 22 - t, 2);
	      };
	    },
	    Elastic: function Elastic(amplitude, period) {
	      if (amplitude === void 0) amplitude = 1;
	      if (period === void 0) period = .5;
	      var a = minMax(amplitude, 1, 10);
	      var p = minMax(period, .1, 2);
	      return function (t) {
	        return t === 0 || t === 1 ? t : -a * Math.pow(2, 10 * (t - 1)) * Math.sin((t - 1 - p / (Math.PI * 2) * Math.asin(1 / a)) * (Math.PI * 2) / p);
	      };
	    }
	  };
	  var baseEasings = ['Quad', 'Cubic', 'Quart', 'Quint', 'Expo'];
	  baseEasings.forEach(function (name, i) {
	    functionEasings[name] = function () {
	      return function (t) {
	        return Math.pow(t, i + 2);
	      };
	    };
	  });
	  Object.keys(functionEasings).forEach(function (name) {
	    var easeIn = functionEasings[name];
	    eases['easeIn' + name] = easeIn;

	    eases['easeOut' + name] = function (a, b) {
	      return function (t) {
	        return 1 - easeIn(a, b)(1 - t);
	      };
	    };

	    eases['easeInOut' + name] = function (a, b) {
	      return function (t) {
	        return t < 0.5 ? easeIn(a, b)(t * 2) / 2 : 1 - easeIn(a, b)(t * -2 + 2) / 2;
	      };
	    };
	  });
	  return eases;
	}();

	function parseEasings(easing, duration) {
	  if (is.fnc(easing)) {
	    return easing;
	  }

	  var name = easing.split('(')[0];
	  var ease = penner[name];
	  var args = parseEasingParameters(easing);

	  switch (name) {
	    case 'spring':
	      return spring(easing, duration);

	    case 'cubicBezier':
	      return applyArguments(bezier, args);

	    case 'steps':
	      return applyArguments(steps, args);

	    default:
	      return applyArguments(ease, args);
	  }
	} // Strings


	function selectString(str) {
	  try {
	    var nodes = document.querySelectorAll(str);
	    return nodes;
	  } catch (e) {
	    return;
	  }
	} // Arrays


	function filterArray(arr, callback) {
	  var len = arr.length;
	  var thisArg = arguments.length >= 2 ? arguments[1] : void 0;
	  var result = [];

	  for (var i = 0; i < len; i++) {
	    if (i in arr) {
	      var val = arr[i];

	      if (callback.call(thisArg, val, i, arr)) {
	        result.push(val);
	      }
	    }
	  }

	  return result;
	}

	function flattenArray(arr) {
	  return arr.reduce(function (a, b) {
	    return a.concat(is.arr(b) ? flattenArray(b) : b);
	  }, []);
	}

	function toArray(o) {
	  if (is.arr(o)) {
	    return o;
	  }

	  if (is.str(o)) {
	    o = selectString(o) || o;
	  }

	  if (o instanceof NodeList || o instanceof HTMLCollection) {
	    return [].slice.call(o);
	  }

	  return [o];
	}

	function arrayContains(arr, val) {
	  return arr.some(function (a) {
	    return a === val;
	  });
	} // Objects


	function cloneObject(o) {
	  var clone = {};

	  for (var p in o) {
	    clone[p] = o[p];
	  }

	  return clone;
	}

	function replaceObjectProps(o1, o2) {
	  var o = cloneObject(o1);

	  for (var p in o1) {
	    o[p] = o2.hasOwnProperty(p) ? o2[p] : o1[p];
	  }

	  return o;
	}

	function mergeObjects(o1, o2) {
	  var o = cloneObject(o1);

	  for (var p in o2) {
	    o[p] = is.und(o1[p]) ? o2[p] : o1[p];
	  }

	  return o;
	} // Colors


	function rgbToRgba(rgbValue) {
	  var rgb = /rgb\((\d+,\s*[\d]+,\s*[\d]+)\)/g.exec(rgbValue);
	  return rgb ? "rgba(" + rgb[1] + ",1)" : rgbValue;
	}

	function hexToRgba(hexValue) {
	  var rgx = /^#?([a-f\d])([a-f\d])([a-f\d])$/i;
	  var hex = hexValue.replace(rgx, function (m, r, g, b) {
	    return r + r + g + g + b + b;
	  });
	  var rgb = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
	  var r = parseInt(rgb[1], 16);
	  var g = parseInt(rgb[2], 16);
	  var b = parseInt(rgb[3], 16);
	  return "rgba(" + r + "," + g + "," + b + ",1)";
	}

	function hslToRgba(hslValue) {
	  var hsl = /hsl\((\d+),\s*([\d.]+)%,\s*([\d.]+)%\)/g.exec(hslValue) || /hsla\((\d+),\s*([\d.]+)%,\s*([\d.]+)%,\s*([\d.]+)\)/g.exec(hslValue);
	  var h = parseInt(hsl[1], 10) / 360;
	  var s = parseInt(hsl[2], 10) / 100;
	  var l = parseInt(hsl[3], 10) / 100;
	  var a = hsl[4] || 1;

	  function hue2rgb(p, q, t) {
	    if (t < 0) {
	      t += 1;
	    }

	    if (t > 1) {
	      t -= 1;
	    }

	    if (t < 1 / 6) {
	      return p + (q - p) * 6 * t;
	    }

	    if (t < 1 / 2) {
	      return q;
	    }

	    if (t < 2 / 3) {
	      return p + (q - p) * (2 / 3 - t) * 6;
	    }

	    return p;
	  }

	  var r, g, b;

	  if (s == 0) {
	    r = g = b = l;
	  } else {
	    var q = l < 0.5 ? l * (1 + s) : l + s - l * s;
	    var p = 2 * l - q;
	    r = hue2rgb(p, q, h + 1 / 3);
	    g = hue2rgb(p, q, h);
	    b = hue2rgb(p, q, h - 1 / 3);
	  }

	  return "rgba(" + r * 255 + "," + g * 255 + "," + b * 255 + "," + a + ")";
	}

	function colorToRgb(val) {
	  if (is.rgb(val)) {
	    return rgbToRgba(val);
	  }

	  if (is.hex(val)) {
	    return hexToRgba(val);
	  }

	  if (is.hsl(val)) {
	    return hslToRgba(val);
	  }
	} // Units


	function getUnit(val) {
	  var split = /[+-]?\d*\.?\d+(?:\.\d+)?(?:[eE][+-]?\d+)?(%|px|pt|em|rem|in|cm|mm|ex|ch|pc|vw|vh|vmin|vmax|deg|rad|turn)?$/.exec(val);

	  if (split) {
	    return split[1];
	  }
	}

	function getTransformUnit(propName) {
	  if (stringContains(propName, 'translate') || propName === 'perspective') {
	    return 'px';
	  }

	  if (stringContains(propName, 'rotate') || stringContains(propName, 'skew')) {
	    return 'deg';
	  }
	} // Values


	function getFunctionValue(val, animatable) {
	  if (!is.fnc(val)) {
	    return val;
	  }

	  return val(animatable.target, animatable.id, animatable.total);
	}

	function getAttribute(el, prop) {
	  return el.getAttribute(prop);
	}

	function convertPxToUnit(el, value, unit) {
	  var valueUnit = getUnit(value);

	  if (arrayContains([unit, 'deg', 'rad', 'turn'], valueUnit)) {
	    return value;
	  }

	  var cached = cache.CSS[value + unit];

	  if (!is.und(cached)) {
	    return cached;
	  }

	  var baseline = 100;
	  var tempEl = document.createElement(el.tagName);
	  var parentEl = el.parentNode && el.parentNode !== document ? el.parentNode : document.body;
	  parentEl.appendChild(tempEl);
	  tempEl.style.position = 'absolute';
	  tempEl.style.width = baseline + unit;
	  var factor = baseline / tempEl.offsetWidth;
	  parentEl.removeChild(tempEl);
	  var convertedUnit = factor * parseFloat(value);
	  cache.CSS[value + unit] = convertedUnit;
	  return convertedUnit;
	}

	function getCSSValue(el, prop, unit) {
	  if (prop in el.style) {
	    var uppercasePropName = prop.replace(/([a-z])([A-Z])/g, '$1-$2').toLowerCase();
	    var value = el.style[prop] || getComputedStyle(el).getPropertyValue(uppercasePropName) || '0';
	    return unit ? convertPxToUnit(el, value, unit) : value;
	  }
	}

	function getAnimationType(el, prop) {
	  if (is.dom(el) && !is.inp(el) && (getAttribute(el, prop) || is.svg(el) && el[prop])) {
	    return 'attribute';
	  }

	  if (is.dom(el) && arrayContains(validTransforms, prop)) {
	    return 'transform';
	  }

	  if (is.dom(el) && prop !== 'transform' && getCSSValue(el, prop)) {
	    return 'css';
	  }

	  if (el[prop] != null) {
	    return 'object';
	  }
	}

	function getElementTransforms(el) {
	  if (!is.dom(el)) {
	    return;
	  }

	  var str = el.style.transform || '';
	  var reg = /(\w+)\(([^)]*)\)/g;
	  var transforms = new Map();
	  var m;

	  while (m = reg.exec(str)) {
	    transforms.set(m[1], m[2]);
	  }

	  return transforms;
	}

	function getTransformValue(el, propName, animatable, unit) {
	  var defaultVal = stringContains(propName, 'scale') ? 1 : 0 + getTransformUnit(propName);
	  var value = getElementTransforms(el).get(propName) || defaultVal;

	  if (animatable) {
	    animatable.transforms.list.set(propName, value);
	    animatable.transforms['last'] = propName;
	  }

	  return unit ? convertPxToUnit(el, value, unit) : value;
	}

	function getOriginalTargetValue(target, propName, unit, animatable) {
	  switch (getAnimationType(target, propName)) {
	    case 'transform':
	      return getTransformValue(target, propName, animatable, unit);

	    case 'css':
	      return getCSSValue(target, propName, unit);

	    case 'attribute':
	      return getAttribute(target, propName);

	    default:
	      return target[propName] || 0;
	  }
	}

	function getRelativeValue(to, from) {
	  var operator = /^(\*=|\+=|-=)/.exec(to);

	  if (!operator) {
	    return to;
	  }

	  var u = getUnit(to) || 0;
	  var x = parseFloat(from);
	  var y = parseFloat(to.replace(operator[0], ''));

	  switch (operator[0][0]) {
	    case '+':
	      return x + y + u;

	    case '-':
	      return x - y + u;

	    case '*':
	      return x * y + u;
	  }
	}

	function validateValue(val, unit) {
	  if (is.col(val)) {
	    return colorToRgb(val);
	  }

	  if (/\s/g.test(val)) {
	    return val;
	  }

	  var originalUnit = getUnit(val);
	  var unitLess = originalUnit ? val.substr(0, val.length - originalUnit.length) : val;

	  if (unit) {
	    return unitLess + unit;
	  }

	  return unitLess;
	} // getTotalLength() equivalent for circle, rect, polyline, polygon and line shapes
	// adapted from https://gist.github.com/SebLambla/3e0550c496c236709744


	function getDistance(p1, p2) {
	  return Math.sqrt(Math.pow(p2.x - p1.x, 2) + Math.pow(p2.y - p1.y, 2));
	}

	function getCircleLength(el) {
	  return Math.PI * 2 * getAttribute(el, 'r');
	}

	function getRectLength(el) {
	  return getAttribute(el, 'width') * 2 + getAttribute(el, 'height') * 2;
	}

	function getLineLength(el) {
	  return getDistance({
	    x: getAttribute(el, 'x1'),
	    y: getAttribute(el, 'y1')
	  }, {
	    x: getAttribute(el, 'x2'),
	    y: getAttribute(el, 'y2')
	  });
	}

	function getPolylineLength(el) {
	  var points = el.points;
	  var totalLength = 0;
	  var previousPos;

	  for (var i = 0; i < points.numberOfItems; i++) {
	    var currentPos = points.getItem(i);

	    if (i > 0) {
	      totalLength += getDistance(previousPos, currentPos);
	    }

	    previousPos = currentPos;
	  }

	  return totalLength;
	}

	function getPolygonLength(el) {
	  var points = el.points;
	  return getPolylineLength(el) + getDistance(points.getItem(points.numberOfItems - 1), points.getItem(0));
	} // Path animation


	function getTotalLength(el) {
	  if (el.getTotalLength) {
	    return el.getTotalLength();
	  }

	  switch (el.tagName.toLowerCase()) {
	    case 'circle':
	      return getCircleLength(el);

	    case 'rect':
	      return getRectLength(el);

	    case 'line':
	      return getLineLength(el);

	    case 'polyline':
	      return getPolylineLength(el);

	    case 'polygon':
	      return getPolygonLength(el);
	  }
	}

	function setDashoffset(el) {
	  var pathLength = getTotalLength(el);
	  el.setAttribute('stroke-dasharray', pathLength);
	  return pathLength;
	} // Motion path


	function getParentSvgEl(el) {
	  var parentEl = el.parentNode;

	  while (is.svg(parentEl)) {
	    if (!is.svg(parentEl.parentNode)) {
	      break;
	    }

	    parentEl = parentEl.parentNode;
	  }

	  return parentEl;
	}

	function getParentSvg(pathEl, svgData) {
	  var svg = svgData || {};
	  var parentSvgEl = svg.el || getParentSvgEl(pathEl);
	  var rect = parentSvgEl.getBoundingClientRect();
	  var viewBoxAttr = getAttribute(parentSvgEl, 'viewBox');
	  var width = rect.width;
	  var height = rect.height;
	  var viewBox = svg.viewBox || (viewBoxAttr ? viewBoxAttr.split(' ') : [0, 0, width, height]);
	  return {
	    el: parentSvgEl,
	    viewBox: viewBox,
	    x: viewBox[0] / 1,
	    y: viewBox[1] / 1,
	    w: width / viewBox[2],
	    h: height / viewBox[3]
	  };
	}

	function getPath(path, percent) {
	  var pathEl = is.str(path) ? selectString(path)[0] : path;
	  var p = percent || 100;
	  return function (property) {
	    return {
	      property: property,
	      el: pathEl,
	      svg: getParentSvg(pathEl),
	      totalLength: getTotalLength(pathEl) * (p / 100)
	    };
	  };
	}

	function getPathProgress(path, progress) {
	  function point(offset) {
	    if (offset === void 0) offset = 0;
	    var l = progress + offset >= 1 ? progress + offset : 0;
	    return path.el.getPointAtLength(l);
	  }

	  var svg = getParentSvg(path.el, path.svg);
	  var p = point();
	  var p0 = point(-1);
	  var p1 = point(+1);

	  switch (path.property) {
	    case 'x':
	      return (p.x - svg.x) * svg.w;

	    case 'y':
	      return (p.y - svg.y) * svg.h;

	    case 'angle':
	      return Math.atan2(p1.y - p0.y, p1.x - p0.x) * 180 / Math.PI;
	  }
	} // Decompose value


	function decomposeValue(val, unit) {
	  // const rgx = /-?\d*\.?\d+/g; // handles basic numbers
	  // const rgx = /[+-]?\d+(?:\.\d+)?(?:[eE][+-]?\d+)?/g; // handles exponents notation
	  var rgx = /[+-]?\d*\.?\d+(?:\.\d+)?(?:[eE][+-]?\d+)?/g; // handles exponents notation

	  var value = validateValue(is.pth(val) ? val.totalLength : val, unit) + '';
	  return {
	    original: value,
	    numbers: value.match(rgx) ? value.match(rgx).map(Number) : [0],
	    strings: is.str(val) || unit ? value.split(rgx) : []
	  };
	} // Animatables


	function parseTargets(targets) {
	  var targetsArray = targets ? flattenArray(is.arr(targets) ? targets.map(toArray) : toArray(targets)) : [];
	  return filterArray(targetsArray, function (item, pos, self) {
	    return self.indexOf(item) === pos;
	  });
	}

	function getAnimatables(targets) {
	  var parsed = parseTargets(targets);
	  return parsed.map(function (t, i) {
	    return {
	      target: t,
	      id: i,
	      total: parsed.length,
	      transforms: {
	        list: getElementTransforms(t)
	      }
	    };
	  });
	} // Properties


	function normalizePropertyTweens(prop, tweenSettings) {
	  var settings = cloneObject(tweenSettings); // Override duration if easing is a spring

	  if (/^spring/.test(settings.easing)) {
	    settings.duration = spring(settings.easing);
	  }

	  if (is.arr(prop)) {
	    var l = prop.length;
	    var isFromTo = l === 2 && !is.obj(prop[0]);

	    if (!isFromTo) {
	      // Duration divided by the number of tweens
	      if (!is.fnc(tweenSettings.duration)) {
	        settings.duration = tweenSettings.duration / l;
	      }
	    } else {
	      // Transform [from, to] values shorthand to a valid tween value
	      prop = {
	        value: prop
	      };
	    }
	  }

	  var propArray = is.arr(prop) ? prop : [prop];
	  return propArray.map(function (v, i) {
	    var obj = is.obj(v) && !is.pth(v) ? v : {
	      value: v
	    }; // Default delay value should only be applied to the first tween

	    if (is.und(obj.delay)) {
	      obj.delay = !i ? tweenSettings.delay : 0;
	    } // Default endDelay value should only be applied to the last tween


	    if (is.und(obj.endDelay)) {
	      obj.endDelay = i === propArray.length - 1 ? tweenSettings.endDelay : 0;
	    }

	    return obj;
	  }).map(function (k) {
	    return mergeObjects(k, settings);
	  });
	}

	function flattenKeyframes(keyframes) {
	  var propertyNames = filterArray(flattenArray(keyframes.map(function (key) {
	    return Object.keys(key);
	  })), function (p) {
	    return is.key(p);
	  }).reduce(function (a, b) {
	    if (a.indexOf(b) < 0) {
	      a.push(b);
	    }

	    return a;
	  }, []);
	  var properties = {};

	  var loop = function loop(i) {
	    var propName = propertyNames[i];
	    properties[propName] = keyframes.map(function (key) {
	      var newKey = {};

	      for (var p in key) {
	        if (is.key(p)) {
	          if (p == propName) {
	            newKey.value = key[p];
	          }
	        } else {
	          newKey[p] = key[p];
	        }
	      }

	      return newKey;
	    });
	  };

	  for (var i = 0; i < propertyNames.length; i++) {
	    loop(i);
	  }

	  return properties;
	}

	function getProperties(tweenSettings, params) {
	  var properties = [];
	  var keyframes = params.keyframes;

	  if (keyframes) {
	    params = mergeObjects(flattenKeyframes(keyframes), params);
	  }

	  for (var p in params) {
	    if (is.key(p)) {
	      properties.push({
	        name: p,
	        tweens: normalizePropertyTweens(params[p], tweenSettings)
	      });
	    }
	  }

	  return properties;
	} // Tweens


	function normalizeTweenValues(tween, animatable) {
	  var t = {};

	  for (var p in tween) {
	    var value = getFunctionValue(tween[p], animatable);

	    if (is.arr(value)) {
	      value = value.map(function (v) {
	        return getFunctionValue(v, animatable);
	      });

	      if (value.length === 1) {
	        value = value[0];
	      }
	    }

	    t[p] = value;
	  }

	  t.duration = parseFloat(t.duration);
	  t.delay = parseFloat(t.delay);
	  return t;
	}

	function normalizeTweens(prop, animatable) {
	  var previousTween;
	  return prop.tweens.map(function (t) {
	    var tween = normalizeTweenValues(t, animatable);
	    var tweenValue = tween.value;
	    var to = is.arr(tweenValue) ? tweenValue[1] : tweenValue;
	    var toUnit = getUnit(to);
	    var originalValue = getOriginalTargetValue(animatable.target, prop.name, toUnit, animatable);
	    var previousValue = previousTween ? previousTween.to.original : originalValue;
	    var from = is.arr(tweenValue) ? tweenValue[0] : previousValue;
	    var fromUnit = getUnit(from) || getUnit(originalValue);
	    var unit = toUnit || fromUnit;

	    if (is.und(to)) {
	      to = previousValue;
	    }

	    tween.from = decomposeValue(from, unit);
	    tween.to = decomposeValue(getRelativeValue(to, from), unit);
	    tween.start = previousTween ? previousTween.end : 0;
	    tween.end = tween.start + tween.delay + tween.duration + tween.endDelay;
	    tween.easing = parseEasings(tween.easing, tween.duration);
	    tween.isPath = is.pth(tweenValue);
	    tween.isColor = is.col(tween.from.original);

	    if (tween.isColor) {
	      tween.round = 1;
	    }

	    previousTween = tween;
	    return tween;
	  });
	} // Tween progress


	var setProgressValue = {
	  css: function css(t, p, v) {
	    return t.style[p] = v;
	  },
	  attribute: function attribute(t, p, v) {
	    return t.setAttribute(p, v);
	  },
	  object: function object(t, p, v) {
	    return t[p] = v;
	  },
	  transform: function transform(t, p, v, transforms, manual) {
	    transforms.list.set(p, v);

	    if (p === transforms.last || manual) {
	      var str = '';
	      transforms.list.forEach(function (value, prop) {
	        str += prop + "(" + value + ") ";
	      });
	      t.style.transform = str;
	    }
	  }
	}; // Set Value helper

	function setTargetsValue(targets, properties) {
	  var animatables = getAnimatables(targets);
	  animatables.forEach(function (animatable) {
	    for (var property in properties) {
	      var value = getFunctionValue(properties[property], animatable);
	      var target = animatable.target;
	      var valueUnit = getUnit(value);
	      var originalValue = getOriginalTargetValue(target, property, valueUnit, animatable);
	      var unit = valueUnit || getUnit(originalValue);
	      var to = getRelativeValue(validateValue(value, unit), originalValue);
	      var animType = getAnimationType(target, property);
	      setProgressValue[animType](target, property, to, animatable.transforms, true);
	    }
	  });
	} // Animations


	function createAnimation(animatable, prop) {
	  var animType = getAnimationType(animatable.target, prop.name);

	  if (animType) {
	    var tweens = normalizeTweens(prop, animatable);
	    var lastTween = tweens[tweens.length - 1];
	    return {
	      type: animType,
	      property: prop.name,
	      animatable: animatable,
	      tweens: tweens,
	      duration: lastTween.end,
	      delay: tweens[0].delay,
	      endDelay: lastTween.endDelay
	    };
	  }
	}

	function getAnimations(animatables, properties) {
	  return filterArray(flattenArray(animatables.map(function (animatable) {
	    return properties.map(function (prop) {
	      return createAnimation(animatable, prop);
	    });
	  })), function (a) {
	    return !is.und(a);
	  });
	} // Create Instance


	function getInstanceTimings(animations, tweenSettings) {
	  var animLength = animations.length;

	  var getTlOffset = function getTlOffset(anim) {
	    return anim.timelineOffset ? anim.timelineOffset : 0;
	  };

	  var timings = {};
	  timings.duration = animLength ? Math.max.apply(Math, animations.map(function (anim) {
	    return getTlOffset(anim) + anim.duration;
	  })) : tweenSettings.duration;
	  timings.delay = animLength ? Math.min.apply(Math, animations.map(function (anim) {
	    return getTlOffset(anim) + anim.delay;
	  })) : tweenSettings.delay;
	  timings.endDelay = animLength ? timings.duration - Math.max.apply(Math, animations.map(function (anim) {
	    return getTlOffset(anim) + anim.duration - anim.endDelay;
	  })) : tweenSettings.endDelay;
	  return timings;
	}

	var instanceID = 0;

	function createNewInstance(params) {
	  var instanceSettings = replaceObjectProps(defaultInstanceSettings, params);
	  var tweenSettings = replaceObjectProps(defaultTweenSettings, params);
	  var properties = getProperties(tweenSettings, params);
	  var animatables = getAnimatables(params.targets);
	  var animations = getAnimations(animatables, properties);
	  var timings = getInstanceTimings(animations, tweenSettings);
	  var id = instanceID;
	  instanceID++;
	  return mergeObjects(instanceSettings, {
	    id: id,
	    children: [],
	    animatables: animatables,
	    animations: animations,
	    duration: timings.duration,
	    delay: timings.delay,
	    endDelay: timings.endDelay
	  });
	} // Core


	var activeInstances = [];
	var pausedInstances = [];
	var raf;

	var engine = function () {
	  function play() {
	    raf = requestAnimationFrame(step);
	  }

	  function step(t) {
	    var activeInstancesLength = activeInstances.length;

	    if (activeInstancesLength) {
	      var i = 0;

	      while (i < activeInstancesLength) {
	        var activeInstance = activeInstances[i];

	        if (!activeInstance.paused) {
	          activeInstance.tick(t);
	        } else {
	          var instanceIndex = activeInstances.indexOf(activeInstance);

	          if (instanceIndex > -1) {
	            activeInstances.splice(instanceIndex, 1);
	            activeInstancesLength = activeInstances.length;
	          }
	        }

	        i++;
	      }

	      play();
	    } else {
	      raf = cancelAnimationFrame(raf);
	    }
	  }

	  return play;
	}();

	function handleVisibilityChange() {
	  if (document.hidden) {
	    activeInstances.forEach(function (ins) {
	      return ins.pause();
	    });
	    pausedInstances = activeInstances.slice(0);
	    anime.running = activeInstances = [];
	  } else {
	    pausedInstances.forEach(function (ins) {
	      return ins.play();
	    });
	  }
	}

	if (typeof document !== 'undefined') {
	  document.addEventListener('visibilitychange', handleVisibilityChange);
	} // Public Instance


	function anime(params) {
	  if (params === void 0) params = {};
	  var startTime = 0,
	      lastTime = 0,
	      now = 0;
	  var children,
	      childrenLength = 0;
	  var resolve = null;

	  function makePromise(instance) {
	    var promise = window.Promise && new Promise(function (_resolve) {
	      return resolve = _resolve;
	    });
	    instance.finished = promise;
	    return promise;
	  }

	  var instance = createNewInstance(params);
	  var promise = makePromise(instance);

	  function toggleInstanceDirection() {
	    var direction = instance.direction;

	    if (direction !== 'alternate') {
	      instance.direction = direction !== 'normal' ? 'normal' : 'reverse';
	    }

	    instance.reversed = !instance.reversed;
	    children.forEach(function (child) {
	      return child.reversed = instance.reversed;
	    });
	  }

	  function adjustTime(time) {
	    return instance.reversed ? instance.duration - time : time;
	  }

	  function resetTime() {
	    startTime = 0;
	    lastTime = adjustTime(instance.currentTime) * (1 / anime.speed);
	  }

	  function seekChild(time, child) {
	    if (child) {
	      child.seek(time - child.timelineOffset);
	    }
	  }

	  function syncInstanceChildren(time) {
	    if (!instance.reversePlayback) {
	      for (var i = 0; i < childrenLength; i++) {
	        seekChild(time, children[i]);
	      }
	    } else {
	      for (var i$1 = childrenLength; i$1--;) {
	        seekChild(time, children[i$1]);
	      }
	    }
	  }

	  function setAnimationsProgress(insTime) {
	    var i = 0;
	    var animations = instance.animations;
	    var animationsLength = animations.length;

	    while (i < animationsLength) {
	      var anim = animations[i];
	      var animatable = anim.animatable;
	      var tweens = anim.tweens;
	      var tweenLength = tweens.length - 1;
	      var tween = tweens[tweenLength]; // Only check for keyframes if there is more than one tween

	      if (tweenLength) {
	        tween = filterArray(tweens, function (t) {
	          return insTime < t.end;
	        })[0] || tween;
	      }

	      var elapsed = minMax(insTime - tween.start - tween.delay, 0, tween.duration) / tween.duration;
	      var eased = isNaN(elapsed) ? 1 : tween.easing(elapsed);
	      var strings = tween.to.strings;
	      var round = tween.round;
	      var numbers = [];
	      var toNumbersLength = tween.to.numbers.length;
	      var progress = void 0;

	      for (var n = 0; n < toNumbersLength; n++) {
	        var value = void 0;
	        var toNumber = tween.to.numbers[n];
	        var fromNumber = tween.from.numbers[n] || 0;

	        if (!tween.isPath) {
	          value = fromNumber + eased * (toNumber - fromNumber);
	        } else {
	          value = getPathProgress(tween.value, eased * toNumber);
	        }

	        if (round) {
	          if (!(tween.isColor && n > 2)) {
	            value = Math.round(value * round) / round;
	          }
	        }

	        numbers.push(value);
	      } // Manual Array.reduce for better performances


	      var stringsLength = strings.length;

	      if (!stringsLength) {
	        progress = numbers[0];
	      } else {
	        progress = strings[0];

	        for (var s = 0; s < stringsLength; s++) {
	          var a = strings[s];
	          var b = strings[s + 1];
	          var n$1 = numbers[s];

	          if (!isNaN(n$1)) {
	            if (!b) {
	              progress += n$1 + ' ';
	            } else {
	              progress += n$1 + b;
	            }
	          }
	        }
	      }

	      setProgressValue[anim.type](animatable.target, anim.property, progress, animatable.transforms);
	      anim.currentValue = progress;
	      i++;
	    }
	  }

	  function setCallback(cb) {
	    if (instance[cb] && !instance.passThrough) {
	      instance[cb](instance);
	    }
	  }

	  function countIteration() {
	    if (instance.remaining && instance.remaining !== true) {
	      instance.remaining--;
	    }
	  }

	  function setInstanceProgress(engineTime) {
	    var insDuration = instance.duration;
	    var insDelay = instance.delay;
	    var insEndDelay = insDuration - instance.endDelay;
	    var insTime = adjustTime(engineTime);
	    instance.progress = minMax(insTime / insDuration * 100, 0, 100);
	    instance.reversePlayback = insTime < instance.currentTime;

	    if (children) {
	      syncInstanceChildren(insTime);
	    }

	    if (!instance.began && instance.currentTime > 0) {
	      instance.began = true;
	      setCallback('begin');
	    }

	    if (!instance.loopBegan && instance.currentTime > 0) {
	      instance.loopBegan = true;
	      setCallback('loopBegin');
	    }

	    if (insTime <= insDelay && instance.currentTime !== 0) {
	      setAnimationsProgress(0);
	    }

	    if (insTime >= insEndDelay && instance.currentTime !== insDuration || !insDuration) {
	      setAnimationsProgress(insDuration);
	    }

	    if (insTime > insDelay && insTime < insEndDelay) {
	      if (!instance.changeBegan) {
	        instance.changeBegan = true;
	        instance.changeCompleted = false;
	        setCallback('changeBegin');
	      }

	      setCallback('change');
	      setAnimationsProgress(insTime);
	    } else {
	      if (instance.changeBegan) {
	        instance.changeCompleted = true;
	        instance.changeBegan = false;
	        setCallback('changeComplete');
	      }
	    }

	    instance.currentTime = minMax(insTime, 0, insDuration);

	    if (instance.began) {
	      setCallback('update');
	    }

	    if (engineTime >= insDuration) {
	      lastTime = 0;
	      countIteration();

	      if (!instance.remaining) {
	        instance.paused = true;

	        if (!instance.completed) {
	          instance.completed = true;
	          setCallback('loopComplete');
	          setCallback('complete');

	          if (!instance.passThrough && 'Promise' in window) {
	            resolve();
	            promise = makePromise(instance);
	          }
	        }
	      } else {
	        startTime = now;
	        setCallback('loopComplete');
	        instance.loopBegan = false;

	        if (instance.direction === 'alternate') {
	          toggleInstanceDirection();
	        }
	      }
	    }
	  }

	  instance.reset = function () {
	    var direction = instance.direction;
	    instance.passThrough = false;
	    instance.currentTime = 0;
	    instance.progress = 0;
	    instance.paused = true;
	    instance.began = false;
	    instance.loopBegan = false;
	    instance.changeBegan = false;
	    instance.completed = false;
	    instance.changeCompleted = false;
	    instance.reversePlayback = false;
	    instance.reversed = direction === 'reverse';
	    instance.remaining = instance.loop;
	    children = instance.children;
	    childrenLength = children.length;

	    for (var i = childrenLength; i--;) {
	      instance.children[i].reset();
	    }

	    if (instance.reversed && instance.loop !== true || direction === 'alternate' && instance.loop === 1) {
	      instance.remaining++;
	    }

	    setAnimationsProgress(instance.reversed ? instance.duration : 0);
	  }; // Set Value helper


	  instance.set = function (targets, properties) {
	    setTargetsValue(targets, properties);
	    return instance;
	  };

	  instance.tick = function (t) {
	    now = t;

	    if (!startTime) {
	      startTime = now;
	    }

	    setInstanceProgress((now + (lastTime - startTime)) * anime.speed);
	  };

	  instance.seek = function (time) {
	    setInstanceProgress(adjustTime(time));
	  };

	  instance.pause = function () {
	    instance.paused = true;
	    resetTime();
	  };

	  instance.play = function () {
	    if (!instance.paused) {
	      return;
	    }

	    if (instance.completed) {
	      instance.reset();
	    }

	    instance.paused = false;
	    activeInstances.push(instance);
	    resetTime();

	    if (!raf) {
	      engine();
	    }
	  };

	  instance.reverse = function () {
	    toggleInstanceDirection();
	    resetTime();
	  };

	  instance.restart = function () {
	    instance.reset();
	    instance.play();
	  };

	  instance.reset();

	  if (instance.autoplay) {
	    instance.play();
	  }

	  return instance;
	} // Remove targets from animation


	function removeTargetsFromAnimations(targetsArray, animations) {
	  for (var a = animations.length; a--;) {
	    if (arrayContains(targetsArray, animations[a].animatable.target)) {
	      animations.splice(a, 1);
	    }
	  }
	}

	function removeTargets(targets) {
	  var targetsArray = parseTargets(targets);

	  for (var i = activeInstances.length; i--;) {
	    var instance = activeInstances[i];
	    var animations = instance.animations;
	    var children = instance.children;
	    removeTargetsFromAnimations(targetsArray, animations);

	    for (var c = children.length; c--;) {
	      var child = children[c];
	      var childAnimations = child.animations;
	      removeTargetsFromAnimations(targetsArray, childAnimations);

	      if (!childAnimations.length && !child.children.length) {
	        children.splice(c, 1);
	      }
	    }

	    if (!animations.length && !children.length) {
	      instance.pause();
	    }
	  }
	} // Stagger helpers


	function stagger(val, params) {
	  if (params === void 0) params = {};
	  var direction = params.direction || 'normal';
	  var easing = params.easing ? parseEasings(params.easing) : null;
	  var grid = params.grid;
	  var axis = params.axis;
	  var fromIndex = params.from || 0;
	  var fromFirst = fromIndex === 'first';
	  var fromCenter = fromIndex === 'center';
	  var fromLast = fromIndex === 'last';
	  var isRange = is.arr(val);
	  var val1 = isRange ? parseFloat(val[0]) : parseFloat(val);
	  var val2 = isRange ? parseFloat(val[1]) : 0;
	  var unit = getUnit(isRange ? val[1] : val) || 0;
	  var start = params.start || 0 + (isRange ? val1 : 0);
	  var values = [];
	  var maxValue = 0;
	  return function (el, i, t) {
	    if (fromFirst) {
	      fromIndex = 0;
	    }

	    if (fromCenter) {
	      fromIndex = (t - 1) / 2;
	    }

	    if (fromLast) {
	      fromIndex = t - 1;
	    }

	    if (!values.length) {
	      for (var index = 0; index < t; index++) {
	        if (!grid) {
	          values.push(Math.abs(fromIndex - index));
	        } else {
	          var fromX = !fromCenter ? fromIndex % grid[0] : (grid[0] - 1) / 2;
	          var fromY = !fromCenter ? Math.floor(fromIndex / grid[0]) : (grid[1] - 1) / 2;
	          var toX = index % grid[0];
	          var toY = Math.floor(index / grid[0]);
	          var distanceX = fromX - toX;
	          var distanceY = fromY - toY;
	          var value = Math.sqrt(distanceX * distanceX + distanceY * distanceY);

	          if (axis === 'x') {
	            value = -distanceX;
	          }

	          if (axis === 'y') {
	            value = -distanceY;
	          }

	          values.push(value);
	        }

	        maxValue = Math.max.apply(Math, values);
	      }

	      if (easing) {
	        values = values.map(function (val) {
	          return easing(val / maxValue) * maxValue;
	        });
	      }

	      if (direction === 'reverse') {
	        values = values.map(function (val) {
	          return axis ? val < 0 ? val * -1 : -val : Math.abs(maxValue - val);
	        });
	      }
	    }

	    var spacing = isRange ? (val2 - val1) / maxValue : val1;
	    return start + spacing * (Math.round(values[i] * 100) / 100) + unit;
	  };
	} // Timeline


	function timeline(params) {
	  if (params === void 0) params = {};
	  var tl = anime(params);
	  tl.duration = 0;

	  tl.add = function (instanceParams, timelineOffset) {
	    var tlIndex = activeInstances.indexOf(tl);
	    var children = tl.children;

	    if (tlIndex > -1) {
	      activeInstances.splice(tlIndex, 1);
	    }

	    function passThrough(ins) {
	      ins.passThrough = true;
	    }

	    for (var i = 0; i < children.length; i++) {
	      passThrough(children[i]);
	    }

	    var insParams = mergeObjects(instanceParams, replaceObjectProps(defaultTweenSettings, params));
	    insParams.targets = insParams.targets || params.targets;
	    var tlDuration = tl.duration;
	    insParams.autoplay = false;
	    insParams.direction = tl.direction;
	    insParams.timelineOffset = is.und(timelineOffset) ? tlDuration : getRelativeValue(timelineOffset, tlDuration);
	    passThrough(tl);
	    tl.seek(insParams.timelineOffset);
	    var ins = anime(insParams);
	    passThrough(ins);
	    children.push(ins);
	    var timings = getInstanceTimings(children, params);
	    tl.delay = timings.delay;
	    tl.endDelay = timings.endDelay;
	    tl.duration = timings.duration;
	    tl.seek(0);
	    tl.reset();

	    if (tl.autoplay) {
	      tl.play();
	    }

	    return tl;
	  };

	  return tl;
	}

	anime.version = '3.1.0';
	anime.speed = 1;
	anime.running = activeInstances;
	anime.remove = removeTargets;
	anime.get = getOriginalTargetValue;
	anime.set = setTargetsValue;
	anime.convertPx = convertPxToUnit;
	anime.path = getPath;
	anime.setDashoffset = setDashoffset;
	anime.stagger = stagger;
	anime.timeline = timeline;
	anime.easing = parseEasings;
	anime.penner = penner;

	anime.random = function (min, max) {
	  return Math.floor(Math.random() * (max - min + 1)) + min;
	};

	var anime_1 = anime;

	/* global Headers btoa */
	var setHeaders = function setHeaders() {
	  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
	      _ref$headers = _ref.headers,
	      headers = _ref$headers === void 0 ? {} : _ref$headers,
	      body = _ref.body,
	      _ref$method = _ref.method,
	      method = _ref$method === void 0 ? 'get' : _ref$method,
	      auth = _ref.auth;

	  if (typeof Headers === 'undefined') {
	    require('cross-fetch/polyfill');
	  }

	  var h = new Headers(headers); // Sets content type to 'application/json' for POST, PUT, PATCH, DELETE requests

	  if (!h.get('content-type') && method !== 'get') {
	    h.set('content-type', 'application/json');
	  }

	  if (auth) {
	    // Basic Auth
	    if (_typeof(auth) === 'object') {
	      var username = auth.username,
	          password = auth.password;
	      if (!username) throw new Error('Username required for basic authentication');
	      if (!password) throw new Error('Password required for basic authentication');
	      var encode;

	      if ('btoa' in window) {
	        encode = btoa;
	      } else {
	        encode = require('btoa');
	      }

	      h.set('Authorization', 'Basic ' + encode("".concat(username, ":").concat(password)));
	    } else {
	      // Bearer Auth
	      h.set('Authorization', "Bearer ".concat(auth));
	    }
	  }

	  return h;
	};

	var queryStringify = function queryStringify(params) {
	  if (!params) return;
	  return Object.entries(params).reduce(function (acc, entry, index) {
	    var _entry = _slicedToArray(entry, 2),
	        param = _entry[0],
	        value = _entry[1];

	    var encoded = index === 0 ? "".concat(param, "=").concat(encodeURIComponent(value)) : "&".concat(param, "=").concat(encodeURIComponent(value));
	    return "".concat(acc).concat(encoded);
	  }, '');
	};
	/**
	 * Appends queries to URL
	 * @param {Object} opts
	 */


	var createURL = function createURL(opts) {
	  var url = opts.url,
	      queries = opts.queries;
	  if (!queries) return url;
	  return "".concat(url, "?").concat(queryStringify(queries));
	};

	var formatBody = function formatBody(opts) {
	  var method = opts.method;
	  if (method === 'get') return;
	  var type = opts.headers.get('content-type');
	  if (!type) return;
	  if (type.includes('x-www-form-urlencoded')) return queryStringify(opts.body);
	  if (type.includes('json')) return JSON.stringify(opts.body);
	  return opts.body;
	}; // Defaults to GET method
	// Defaults content type to application/json
	// Creates authorization headers automatically


	var createRequestOptions = (function () {
	  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
	  var opts = Object.assign({}, options);
	  opts.url = createURL(opts);
	  opts.method = opts.method || 'get';
	  opts.headers = setHeaders(opts);
	  opts.body = formatBody(opts); // Removes options that are not native to Fetch

	  delete opts.auth;
	  return opts;
	});

	// window.fetch response headers contains entries method.
	var getBrowserFetchHeaders = function getBrowserFetchHeaders(response) {
	  var headers = {};

	  var _iterator = _createForOfIteratorHelper(response.headers.entries()),
	      _step;

	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var _step$value = _slicedToArray(_step.value, 2),
	          header = _step$value[0],
	          value = _step$value[1];

	      headers[header] = value;
	    }
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }

	  return headers;
	}; // Node fetch response headers does not contain entries method.


	var getNodeFetchHeaders = function getNodeFetchHeaders(response) {
	  var headers = {};
	  var h = response.headers._headers;

	  for (var header in h) {
	    headers[header] = h[header].join('');
	  }

	  return headers;
	};

	var getHeaders = function getHeaders(response) {
	  return response.headers.entries ? getBrowserFetchHeaders(response) : getNodeFetchHeaders(response);
	};

	var formatOutput = function formatOutput(response, body) {
	  var headers = getHeaders(response);
	  var returnValue = {
	    body: body,
	    headers: headers,
	    response: response,
	    status: response.status,
	    statusText: response.statusText
	  };
	  return response.ok ? Promise.resolve(returnValue) : Promise.reject(returnValue);
	};

	var parseResponse = function parseResponse(response, type) {
	  // Response object can only be used once.
	  // We clone the response object here so users can use it again if they want to.
	  // Checks required because browser support isn't solid.
	  // https://developer.mozilla.org/en-US/docs/Web/API/Response/clone
	  var clone = typeof response.clone === 'function' ? response.clone() : undefined;
	  var passedResponse = clone || response; // This will do response.json(), response.text(), etc.
	  // We use bracket notation to allow multiple types to be parsed at the same time.

	  return response[type]().then(function (body) {
	    return formatOutput(passedResponse, body);
	  });
	};

	var handleResponse = function handleResponse(response) {
	  var type = response.headers.get('content-type');
	  if (type.includes('json')) return parseResponse(response, 'json');
	  if (type.includes('text')) return parseResponse(response, 'text');
	  if (type.includes('image')) return parseResponse(response, 'blob'); // Need to check for FormData, Blob and ArrayBuffer content types

	  throw new Error("zlFetch does not support content-type ".concat(type, " yet"));
	};
	/**
	 * Formats all errors into zlFetch style error
	 * @param {Object} error - The error object
	 */

	var handleError = function handleError(error) {
	  if (error.message === 'Failed to fetch') {
	    /* eslint-disable */
	    return Promise.reject({
	      error: error
	    });
	    /* eslint-enable */
	  }

	  return Promise.reject(error);
	};

	/* globals fetch */

	if (typeof fetch === 'undefined') {
	  require('cross-fetch/polyfill');
	}

	var zlFetch = function zlFetch(url, options) {
	  var opts = createRequestOptions(Object.assign({
	    url: url
	  }, options));
	  return fetch(opts.url, opts).then(handleResponse).catch(handleError);
	}; // ========================
	// Shorthands
	// ========================


	var methods = ['get', 'post', 'put', 'patch', 'delete'];

	var _loop = function _loop() {
	  var method = _methods[_i];

	  zlFetch[method] = function (url, options) {
	    options = Object.assign({
	      method: method
	    }, options);
	    return zlFetch(url, options);
	  };
	};

	for (var _i = 0, _methods = methods; _i < _methods.length; _i++) {
	  _loop();
	}

	var buttonStrings = {
	  start: 'Install',
	  loading: 'Loading...',
	  preparing: 'Preparing...',
	  importing: 'Importing...',
	  uninstalling: 'Uninstalling...'
	};
	/**
	 * Render errors or warnings list and display action buttons.
	 *
	 * @param {string} description
	 * @param {array} warnings
	 * @param {array} buttons
	 *
	 * @return {string}
	 */

	function renderActionMessage(description, warnings) {
	  var buttons = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
	  var str = "<p class=\"kalium-demos__content-pack-view-warnings-description\">".concat(description, "</p>"); // List

	  str += '<ul class="kalium-demos__content-pack-view-warnings">';

	  var _iterator = _createForOfIteratorHelper(warnings),
	      _step;

	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var warning = _step.value;
	      str += "<li>".concat(warning.message, "</li>");
	    }
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }

	  str += '</ul>'; // Buttons

	  if (buttons instanceof Array && buttons.length > 0) {
	    str += '<div class="kalium-demos__content-pack-view-warnings-buttons">';

	    var _iterator2 = _createForOfIteratorHelper(buttons),
	        _step2;

	    try {
	      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	        var button = _step2.value;

	        if (button.link) {
	          str += "<a href=\"".concat(button.link, "\" class=\"").concat(button.class, "\" target=\"_blank\" rel=\"noreferrer noopener\">").concat(button.title, "</a>");
	        } else {
	          str += "<button type=\"button\" class=\"".concat(button.class, "\">").concat(button.title, "</button>");
	        }
	      }
	    } catch (err) {
	      _iterator2.e(err);
	    } finally {
	      _iterator2.f();
	    }

	    str += '</div>';
	  }

	  return str;
	}
	/**
	 * Kalium Import demo content class.
	 *
	 * @version 1.0
	 */


	var Kalium_Import = /*#__PURE__*/function () {
	  /**
	   * Constructor.
	   *
	   * @param {string} contentPackID
	   * @param {$} container
	   * @param {Popup} popup
	   */
	  function Kalium_Import(contentPackID, container, popup) {
	    var _this = this;

	    _classCallCheck(this, Kalium_Import);

	    /**
	     * Content pack ID.
	     *
	     * @type {string}
	     * @public
	     */
	    this.contentPackID = contentPackID;
	    /**
	     * Tasks list array.
	     *
	     * @type {Kalium_Import_Task[]}
	     * @public
	     */

	    this.tasksList = [];
	    /**
	     * Task runner instance.
	     *
	     * @type {Kalium_Import_Task_Runner}
	     * @public
	     */

	    this.taskRunner = null; // Loading state

	    this.isLoading = false; // The popup container

	    this.popup = popup; // DOM container

	    this.$container = jQuery(container); // Required plugins

	    this.$requiredPlugins = this.$container.find('.kalium-demos__content-pack-view-required-plugins [data-plugin-slug]'); // Imports

	    this.$imports = this.$container.find('.kalium-demos__content-pack-view-imports .kalium-demos__content-pack-view-import'); // Import button

	    this.$importButton = this.$container.find('#start_import'); // Uninstall button

	    this.$uninstallButton = this.$container.find('#start_uninstall'); // Progress bar

	    this.$progressContainer = this.$container.find('.kalium-demos__content-pack-view-progress');
	    this.$progressText = this.$progressContainer.find('.kalium-demos__content-pack-view-progress-status-text');
	    this.$progressBarPercentage = this.$progressContainer.find('.kalium-demos__content-pack-view-progress-status-percentage');
	    this.$progressBar = this.$progressContainer.find('.kalium-demos__content-pack-view-progress-bar-fill'); // Import button event

	    this.$importButton.on('click', function (ev) {
	      ev.preventDefault();

	      _this.import();
	    }); // Uninstall button event

	    this.$uninstallButton.on('click', function (ev) {
	      ev.preventDefault();

	      _this.uninstall();
	    }); // Setup WordPress Importer optional post types import

	    this.setupOptionalPostTypesImport(); // Uninstalling content pack

	    if (this.$uninstallButton.length) {
	      // Setup events to toggle uninstall button state
	      this.setupUninstallButtonToggle();
	    } else {
	      // Setup events to toggle import button state
	      this.setupImportButtonToggle();
	    }
	  }
	  /**
	   * Set disabled property for content import fields.
	   *
	   * @param {boolean} disable
	   */


	  _createClass(Kalium_Import, [{
	    key: "disableContentImportFields",
	    value: function disableContentImportFields() {
	      var disable = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

	      var _iterator3 = _createForOfIteratorHelper(this.getContentImportFields()),
	          _step3;

	      try {
	        for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	          var field = _step3.value;
	          field.$input.prop('disabled', disable);
	          field.$argsFields.find('input').prop('disabled', disable);
	        }
	      } catch (err) {
	        _iterator3.e(err);
	      } finally {
	        _iterator3.f();
	      }
	    }
	    /**
	     * Sets event for import field to disable import args fields when checked.
	     *
	     * @return {void}
	     */

	  }, {
	    key: "setupOptionalPostTypesImport",
	    value: function setupOptionalPostTypesImport() {
	      var _iterator4 = _createForOfIteratorHelper(this.$imports),
	          _step4;

	      try {
	        for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	          var importEntry = _step4.value;
	          var $import = jQuery(importEntry); // Only for WordPress Import

	          if ('wordpress-import' === $import.data('import-type')) {
	            (function () {
	              var $importField = $import.find('.kalium-demos__content-pack-view-imports-checkbox input'),
	                  $postTypesArgsFields = $import.find('.kalium-demos__content-pack-view-imports-args-fields [data-field-name="post_types"] input');

	              if ($postTypesArgsFields.length) {
	                // Update input status
	                var updatePostTypesInputState = function updatePostTypesInputState() {
	                  var _iterator5 = _createForOfIteratorHelper($postTypesArgsFields),
	                      _step5;

	                  try {
	                    for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
	                      var postTypeField = _step5.value;
	                      var $postTypeField = jQuery(postTypeField),
	                          fieldValue = $postTypeField.val(),
	                          checked = $importField.is(':checked'); // Check when import field is set to checked

	                      if (checked) {
	                        $postTypeField.prop('checked', true);
	                      } // Except for attachments (media files)


	                      if ('attachment' === fieldValue) {
	                        checked = false;
	                      }

	                      $postTypeField.prop('disabled', checked);
	                    }
	                  } catch (err) {
	                    _iterator5.e(err);
	                  } finally {
	                    _iterator5.f();
	                  }
	                }; // Initial check on load


	                updatePostTypesInputState(); // Assign event to import field input

	                $importField.on('change', updatePostTypesInputState);
	              }
	            })();
	          }
	        }
	      } catch (err) {
	        _iterator4.e(err);
	      } finally {
	        _iterator4.f();
	      }
	    }
	    /**
	     * Sets event for import field to enable uninstall button when one or more checkbox is checked.
	     *
	     * @return {void}
	     */

	  }, {
	    key: "setupImportButtonToggle",
	    value: function setupImportButtonToggle() {
	      var _this2 = this;

	      // Toggle button state
	      var fields = this.getContentImportFields(),
	          toggleButtonState = function toggleButtonState(ev) {
	        var checked = false;

	        var _iterator6 = _createForOfIteratorHelper(fields),
	            _step6;

	        try {
	          for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
	            var field = _step6.value;
	            var isDisabled = field.$input.is(':disabled') || field.$input.hasClass('disabled');

	            if (!isDisabled && field.$input.is(':checked')) {
	              checked = true;
	              break;
	            }
	          }
	        } catch (err) {
	          _iterator6.e(err);
	        } finally {
	          _iterator6.f();
	        }

	        _this2.$importButton.prop('disabled', !checked);
	      }; // Set change event


	      var _iterator7 = _createForOfIteratorHelper(fields),
	          _step7;

	      try {
	        for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
	          var field = _step7.value;
	          field.$input.on('change', toggleButtonState);
	        }
	      } catch (err) {
	        _iterator7.e(err);
	      } finally {
	        _iterator7.f();
	      }
	    }
	    /**
	     * Sets event for import field to enable uninstall button when one or more checkbox is checked.
	     *
	     * @return {void}
	     */

	  }, {
	    key: "setupUninstallButtonToggle",
	    value: function setupUninstallButtonToggle() {
	      var _this3 = this;

	      // Toggle button state
	      var fields = this.getContentImportFields(),
	          toggleButtonState = function toggleButtonState(ev) {
	        var checked = false;

	        var _iterator8 = _createForOfIteratorHelper(fields),
	            _step8;

	        try {
	          for (_iterator8.s(); !(_step8 = _iterator8.n()).done;) {
	            var field = _step8.value;

	            if (field.$input.is(':checked')) {
	              checked = true;
	              break;
	            }
	          }
	        } catch (err) {
	          _iterator8.e(err);
	        } finally {
	          _iterator8.f();
	        }

	        _this3.$uninstallButton.prop('disabled', !checked);
	      }; // Set change event


	      var _iterator9 = _createForOfIteratorHelper(fields),
	          _step9;

	      try {
	        for (_iterator9.s(); !(_step9 = _iterator9.n()).done;) {
	          var field = _step9.value;
	          field.$input.on('change', toggleButtonState);
	        }
	      } catch (err) {
	        _iterator9.e(err);
	      } finally {
	        _iterator9.f();
	      }
	    }
	    /**
	     * Get content-import fields with args field values as well.
	     *
	     * @return {array}
	     */

	  }, {
	    key: "getContentImportFields",
	    value: function getContentImportFields() {
	      var contentImportFields = []; // Populate content import fields

	      this.$imports.each(function (i, importEl) {
	        var $importEl = jQuery(importEl),
	            $field = $importEl.find('.import-field'),
	            fieldLabel = $importEl.find('.kalium-demos__content-pack-view-imports-label').text().trim(),
	            $argsFields = $importEl.find('.kalium-demos__content-pack-view-imports-args-fields [data-field-name]'),
	            argsFields = {}; // Add field entry to array

	        contentImportFields.push({
	          // Props
	          type: $importEl.data('import-type'),
	          id: $field.val(),
	          label: fieldLabel,
	          checked: $field.is(':checked'),
	          argsFields: argsFields,
	          // Elements
	          $importEl: $importEl,
	          $input: $field,
	          $argsFields: $argsFields
	        }); // Populate args fields

	        if ($argsFields.length) {
	          $argsFields.each(function (j, argField) {
	            var $fieldContainer = jQuery(argField),
	                $argField = $fieldContainer.find('input'),
	                fieldName = $fieldContainer.data('field-name'),
	                fieldValue = $argField.val();
	 // Checkbox field

	            {
	              // Only when checked
	              if ($argField.is(':checked')) {
	                if (!argsFields.hasOwnProperty(fieldName)) {
	                  argsFields[fieldName] = [];
	                } // Add args field value


	                argsFields[fieldName].push(fieldValue);
	              }
	            }
	          });
	        }
	      });
	      return contentImportFields;
	    }
	    /**
	     * Get content import field by import id.
	     *
	     * @param {string} importId
	     *
	     * @return {object|undefined}
	     */

	  }, {
	    key: "getContentImportField",
	    value: function getContentImportField(importId) {
	      return this.getContentImportFields().filter(function (contentImportField) {
	        return importId === contentImportField.id;
	      }).pop();
	    }
	    /**
	     * Make an Import Content API content call.
	     *
	     * @param {string} endpoint
	     * @param {object} data
	     *
	     * @return Promise
	     */

	  }, {
	    key: "api",
	    value: function api(endpoint) {
	      var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	      var url = ajaxurl + '?action=kalium_demos_import_actions'; // Endpoint data

	      jQuery.extend(data, {
	        contentPack: this.contentPackID,
	        contentPackAction: endpoint
	      });
	      return zlFetch(url, {
	        method: 'post',
	        headers: {
	          'content-type': 'application/x-www-form-urlencoded'
	        },
	        body: data
	      });
	    }
	    /**
	     * Import process start.
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "importStart",
	    value: function importStart() {
	      var _this4 = this;

	      return new Promise(function (resolve, reject) {
	        // Disable content import fields
	        _this4.disableContentImportFields(true); // Resolve


	        resolve();
	      });
	    }
	    /**
	     * Check server limits.
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "checkServerLimits",
	    value: function checkServerLimits() {
	      var _this5 = this;

	      return new Promise(function (resolve, reject) {
	        // Set progress status
	        _this5.setProgressStatus('Checking server limits...'); // Check server limits


	        _this5.api('check-server-limits').then(function (response) {
	          // Vars
	          var wpMemoryLimit = response.body.wp_memory_limit,
	              maxExecutionTime = response.body.max_execution_time,
	              domdocument = response.body.domdocument,
	              remoteGet = response.body.remote_get,
	              filesystemMethod = response.body.filesystem_method,
	              recommendedMemoryLimit = response.body.recommended_memory_limit,
	              recommendedExecutionTime = response.body.recommended_execution_time,
	              errors = [],
	              warnings = []; // Convert memory limit to KB

	          wpMemoryLimit = wpMemoryLimit / 1024 / 1024; // Memory limit warning

	          if (wpMemoryLimit < recommendedMemoryLimit) {
	            warnings.push({
	              message: "Minimum recommended memory limit is <strong class=\"green\">".concat(recommendedMemoryLimit, " MB</strong>. Your current memory limit is <strong class=\"red\">").concat(wpMemoryLimit, " MB</strong>")
	            });
	          } // Execution time warning


	          if (maxExecutionTime < recommendedExecutionTime) {
	            warnings.push({
	              message: "Minimum recommended execution time is <strong class=\"green\">".concat(recommendedExecutionTime, "</strong> to avoid stopping the import process. Your maximum PHP execution time is <strong class=\"red\">").concat(maxExecutionTime, "</strong>")
	            });
	          } // If remote get doesn't work, then it cannot continue


	          if (remoteGet.errors || remoteGet.response && remoteGet.response.code > 300) {
	            errors.push({
	              message: "Theme API server is not accessible from your site."
	            }); // WP Error

	            if (remoteGet.errors) {
	              for (var errorCode in remoteGet.errors) {
	                errors.push({
	                  message: "".concat(remoteGet.errors[errorCode], " (Error code: ").concat(errorCode, ")")
	                });
	              }
	            } // HTTP errors


	            if (remoteGet.response && (remoteGet.response.code > 300 || remoteGet.response.code < 200)) {
	              errors.push({
	                message: "".concat(remoteGet.response.code, " - ").concat(remoteGet.response.message)
	              });
	            }
	          } // DOMDocument module


	          if (!domdocument) {
	            errors.push({
	              message: 'DOMDocument is not installed on your server, but is required to Import Demo Content data.'
	            });
	          } // Stop the process


	          if (errors.length > 0) {
	            // Show warning popup
	            var errorDescription = 'Critical errors have been identified in your server, therefore the import process cannot continue because of the following reasons:',
	                errorButtons = [{
	              class: 'button button-primary button-learn-more',
	              title: 'Learn more',
	              link: 'https://documentation.laborator.co/kb/kalium/kalium-server-requirements/'
	            }, {
	              class: 'button button-close',
	              title: 'Close'
	            }],
	                errorPopup = new Popup('Error (import process could not continue)', renderActionMessage(errorDescription, errors, errorButtons), {
	              dismissable: false,
	              dismissOverlay: false,
	              minWidth: 600,
	              hideOtherActive: false
	            });
	            errorPopup.open(); // Learn more button

	            errorPopup.$contentBody.on('click', '.button-learn-more', function (ev) {
	              errorPopup.close(); // Reject code 1

	              reject({
	                errCode: 1,
	                reason: 'Process could not continue because of reported errors.'
	              });
	            }); // Close button

	            errorPopup.$contentBody.on('click', '.button-close', function (ev) {
	              errorPopup.close(); // Reject code 1

	              reject({
	                errCode: 1,
	                reason: 'Process could not continue because of reported errors.'
	              });
	            });
	          } // Continue (or dismiss) after reading the warnings
	          else if (warnings.length > 0) {
	              // Show warning popup
	              var warningDescription = 'Before proceeding with demo content import, please note that the following warnings are reported from sever check:',
	                  warningButtons = [{
	                class: 'button button-primary button-increase-limits',
	                title: 'Increase limits',
	                link: 'https://documentation.laborator.co/kb/general/how-to-upgrade-php-version-and-increase-server-limits/'
	              }, {
	                class: 'button button-continue',
	                title: 'Continue'
	              }],
	                  warningPopup = new Popup('Server limits warning', renderActionMessage(warningDescription, warnings, warningButtons), {
	                dismissable: false,
	                dismissOverlay: false,
	                minWidth: 600,
	                hideOtherActive: false
	              });
	              warningPopup.open(); // Increase limits button

	              warningPopup.$contentBody.on('click', '.button-increase-limits', function (ev) {
	                warningPopup.close(); // Reject code 2

	                reject({
	                  errCode: 2,
	                  reason: 'Process stopped by the user.'
	                });
	              }); // Continue button

	              warningPopup.$contentBody.on('click', '.button-continue', function (ev) {
	                warningPopup.close();
	                resolve(response);
	              });
	            } // No warnings or errors reported
	            else {
	                // Resolve
	                resolve(response);
	              } // Update status message


	          _this5.setProgressStatus('');
	        });
	      });
	    }
	    /**
	     * Get tasks list.
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "getTasksList",
	    value: function getTasksList() {
	      var _this6 = this;

	      return new Promise(function (resolve, reject) {
	        // Set progress status
	        _this6.setProgressStatus('Retrieving tasks list...'); // Get tasks list


	        _this6.api('tasks-list').then(function (response) {
	          // On success response
	          if (200 === response.status) {
	            // Resolve when the request is successful
	            resolve(response.body);
	          } else {
	            // Reject when cannot get tasks list
	            reject({
	              errCode: 3,
	              reason: 'Cannot get tasks list!'
	            });
	          }
	        }).catch(function () {
	          return reject();
	        });
	      });
	    }
	    /**
	     * Get uninstall task list for installed content types.
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "getUninstallTaskList",
	    value: function getUninstallTaskList() {
	      var _this7 = this;

	      return new Promise(function (resolve, reject) {
	        // Get uninstall task list
	        _this7.api('uninstall-tasks-list').then(function (response) {
	          // On success response
	          if (200 === response.status) {
	            // Resolve when the request is successful
	            resolve(response.body);
	          } else {
	            // Reject when cannot get tasks list
	            reject({
	              errCode: 3,
	              reason: 'Cannot get tasks list!'
	            });
	          }
	        }).catch(function () {
	          return reject();
	        });
	      });
	    }
	    /**
	     * Register tasks list.
	     *
	     * @param {array} tasksArr
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "registerTasksList",
	    value: function registerTasksList(tasksArr) {
	      var _this8 = this;

	      return new Promise(function (resolve, reject) {
	        // Set progress status
	        _this8.setProgressStatus('Registering tasks...'); // Tasks list


	        var incompleteTasks = 0;
	        /**
	         * Valid content-import task checker.
	         *
	         * @param {Kalium_Import_Task} task
	         *
	         * @return {boolean}
	         */

	        var isValidContentImportTask = function isValidContentImportTask(task) {
	          // Check if content import task is checked (if not, check for args fields)
	          var importId = task.getArg('import_id'),
	              contentImportField = _this8.getContentImportField(importId); // When task is completed, exclude it


	          if (task.completed()) {
	            return false;
	          }

	          return contentImportField && (contentImportField.checked || contentImportField.argsFields.length > 0);
	        }; // Create tasks list


	        var _iterator10 = _createForOfIteratorHelper(tasksArr),
	            _step10;

	        try {
	          for (_iterator10.s(); !(_step10 = _iterator10.n()).done;) {
	            var taskOjb = _step10.value;
	            // Create task instance
	            var task = new Kalium_Import_Task(taskOjb); // Exclude import-content tasks that are not checked

	            if ('content-import' === task.getType() && false === isValidContentImportTask(task)) {
	              continue;
	            } // Register number of incomplete tasks


	            if (!task.completed()) {
	              incompleteTasks++;
	            } // Register tasks list as class variable


	            _this8.tasksList.push(task);
	          } // Resolve if there are tasks to execute

	        } catch (err) {
	          _iterator10.e(err);
	        } finally {
	          _iterator10.f();
	        }

	        if (incompleteTasks > 0) {
	          // Initialize task runner
	          _this8.taskRunner = new Kalium_Import_Task_Runner(_this8); // Resolve

	          resolve(_this8.taskRunner);
	        } else {
	          reject({
	            errCode: 4,
	            reason: 'There are no tasks to complete!'
	          });
	        }
	      });
	    }
	    /**
	     * Install required plugins.
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "installRequiredPlugins",
	    value: function installRequiredPlugins() {
	      // Set progress status
	      this.setProgressStatus('Installing required plugins...'); // Run install plugins task

	      return this.taskRunner.runTasks('plugin-install');
	    }
	    /**
	     * Import content types.
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "importContentTypes",
	    value: function importContentTypes() {
	      // Set progress status
	      this.setProgressStatus('Importing demo content...'); // Set button status

	      this.buttonStatus('importing'); // Run install plugins task

	      return this.taskRunner.runTasks('content-import');
	    }
	    /**
	     * Uninstall content types.
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "uninstallContentTypes",
	    value: function uninstallContentTypes() {
	      // Run install plugins task
	      return this.taskRunner.runTasks('content-import');
	    }
	    /**
	     * Set install complete state.
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "setInstallState",
	    value: function setInstallState() {
	      // Set progress status
	      this.setProgressStatus('Finishing install...');
	      return this.api('set-install-state');
	    }
	    /**
	     * Start import process.
	     *
	     * @return {void}
	     */

	  }, {
	    key: "import",
	    value: function _import() {
	      var _this9 = this;

	      // Change button status
	      this.buttonStatus('preparing'); // Show progress bar

	      this.toggleProgress(true); // Set progress status

	      this.setProgressStatus('Preparing import...'); // Import failed callback

	      var importFailed = function importFailed(err) {
	        return _this9.importFailed(err);
	      }; // Import process start


	      var importStart = this.importStart(); // Check server limits

	      var serverLimitsRequest = importStart.then(function () {
	        return _this9.checkServerLimits();
	      }).catch(importFailed); // Load tasks after server limits

	      var getTasksList = serverLimitsRequest.then(function () {
	        return _this9.getTasksList();
	      }).catch(importFailed); // Register tasks list

	      var registerTasksList = getTasksList.then(function (tasksArr) {
	        return _this9.registerTasksList(tasksArr);
	      }).catch(importFailed); // Install required plugins

	      var installRequiredPlugins = registerTasksList.then(function () {
	        return _this9.installRequiredPlugins();
	      }).catch(importFailed); // Import demo content

	      var contentImport = installRequiredPlugins.then(function () {
	        return _this9.importContentTypes();
	      }).catch(importFailed); // Set install state

	      var setInstallState = contentImport.then(function () {
	        return _this9.setInstallState();
	      }).catch(importFailed); // Import finished

	      setInstallState.then(function () {
	        _this9.importFinished('success');
	      });
	    }
	    /**
	     * Uninstall content packs.
	     *
	     * @return {void}
	     */

	  }, {
	    key: "uninstall",
	    value: function uninstall() {
	      var _this10 = this;

	      // Change button status
	      this.buttonStatus('uninstalling'); // Show progress bar

	      this.toggleProgress(true); // Set progress status

	      this.setProgressStatus('Starting uninstall process...'); // Disable import fields, the process started

	      this.disableContentImportFields(true); // Import failed callback

	      var importFailed = function importFailed(err) {
	        return _this10.importFailed(err);
	      }; // Retrieve uninstall task list


	      var getUninstallTasksList = this.getUninstallTaskList(); // Register task list

	      var registerUninstallTasksList = getUninstallTasksList.then(function (tasksArr) {
	        return _this10.registerTasksList(tasksArr);
	      }).catch(importFailed); // Uninstall content types

	      var uninstallContentTypes = registerUninstallTasksList.then(function () {
	        return _this10.uninstallContentTypes();
	      }).catch(importFailed); // Set install state

	      var setInstallState = uninstallContentTypes.then(function () {
	        return _this10.setInstallState();
	      }).catch(importFailed); // Uninstall finished

	      setInstallState.then(function () {
	        _this10.importFinished('success');
	      });
	    }
	    /**
	     * When import fails.
	     *
	     * @param {Object} error
	     *
	     * @return {Promise}
	     */

	  }, {
	    key: "importFailed",
	    value: function importFailed(error) {
	      this.importFinished('failed');
	      return new Promise(function () {
	        return null;
	      });
	    }
	    /**
	     * Import finished dialog.
	     *
	     * @param {string} type
	     */

	  }, {
	    key: "importFinished",
	    value: function importFinished() {
	      var _this11 = this;

	      var type = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
	      type = 'failed' === type ? type : 'success'; // Hide content pack view

	      var $contentPackView = this.$container.find('.kalium-demos__content-pack-view'),
	          $finishView = jQuery(this.$container.find(".content-import-".concat(type, "-template")).html().replace('{{contentPackName}}', $contentPackView.data('name'))),
	          $errors = $finishView.find('.kalium-demos__content-pack-finish-view-errors'); // Append existing errors

	      var _iterator11 = _createForOfIteratorHelper(this.tasksList),
	          _step11;

	      try {
	        for (_iterator11.s(); !(_step11 = _iterator11.n()).done;) {
	          var task = _step11.value;

	          if (task.getErrors().hasErrors()) {
	            var errors = task.getErrors(),
	                importId = task.getArg('import_id'),
	                contentImportField = this.getContentImportField(importId);

	            if (contentImportField) {
	              $errors.removeClass('hidden');
	              jQuery('<li></li>').append(jQuery('<h4></h4>').append(contentImportField.label)).append(errors.wrapErrors('', {
	                className: 'kalium-demos__content-pack-finish-view-error-description'
	              })).appendTo($errors);
	            }
	          }
	        } // Clicking the link will refresh the page

	      } catch (err) {
	        _iterator11.e(err);
	      } finally {
	        _iterator11.f();
	      }

	      $finishView.find('.kalium-demos__content-pack-finish-view-heading-link').on('click', function () {
	        _this11.close();

	        window.location.reload();
	      }); // Append template to container

	      this.$container.append($finishView); // Dialog height

	      var dialogHeight = $finishView.outerHeight(); // Hide dialog initially

	      $finishView.hide(); // Show dialog with animation

	      anime_1({
	        targets: $contentPackView[0],
	        easing: 'easeInOutSine',
	        opacity: 0,
	        duration: 300,
	        complete: function complete() {
	          return anime_1({
	            targets: $contentPackView[0],
	            easing: 'easeInOutSine',
	            height: dialogHeight,
	            duration: 300,
	            complete: function complete() {
	              // Hide content pack view
	              $contentPackView.hide(); // Show dialog

	              $finishView.show();
	              anime_1({
	                targets: $finishView[0],
	                easing: 'easeInOutSine',
	                opacity: 1,
	                duration: 300,
	                complete: function complete() {}
	              });
	            }
	          });
	        }
	      });
	    }
	    /**
	     * Close popup window.
	     *
	     * @return {void}
	     */

	  }, {
	    key: "close",
	    value: function close() {
	      this.popup.close();
	    }
	    /**
	     * Set button status.
	     *
	     * @param {string} status
	     */

	  }, {
	    key: "buttonStatus",
	    value: function buttonStatus(status) {
	      var $button = jQuery([].concat(_toConsumableArray(this.$importButton.get()), _toConsumableArray(this.$uninstallButton.get()))),
	          buttonStatusIds = Object.keys(buttonStrings); // Status class and text

	      if (-1 !== jQuery.inArray(status, buttonStatusIds)) {
	        $button.removeClass(buttonStatusIds.concat(' ') + ' disabled').addClass(status).html(buttonStrings[status].replace('...', '&hellip;'));
	      } // Disabled states for statuses


	      if (-1 !== jQuery.inArray(status, ['preparing', 'loading', 'importing', 'uninstalling'])) {
	        $button.addClass('disabled');
	      }
	    }
	    /**
	     * Show progress and status.
	     *
	     * @param {boolean} status
	     */

	  }, {
	    key: "toggleProgress",
	    value: function toggleProgress(status) {
	      this.$progressContainer[status ? 'addClass' : 'removeClass']('visible');
	    }
	    /**
	     * Set progress value (range 0-100).
	     *
	     * @param {number} progress
	     */

	  }, {
	    key: "setProgress",
	    value: function setProgress(progress) {
	      var _this12 = this;

	      // Progress constraints
	      if (progress > 100) {
	        progress = 100;
	      } else if (progress < 0) {
	        progress = 0;
	      }

	      var currentProgress = 0;
	      anime_1({
	        targets: this.$progressBar[0],
	        width: "".concat(progress, "%"),
	        easing: 'easeInOutSine',
	        duration: 700,
	        update: function update(anim) {
	          currentProgress = parseInt(anim.animations[0].currentValue, 10);

	          _this12.$progressBarPercentage.text("".concat(currentProgress, "%"));
	        }
	      });
	    }
	    /**
	     * Set progress status.
	     *
	     * @param {string} statusText
	     */

	  }, {
	    key: "setProgressStatus",
	    value: function setProgressStatus(statusText) {
	      this.$progressText.html(statusText.replace('...', '&hellip;'));
	    }
	  }]);

	  return Kalium_Import;
	}(); // Export as default

	/**
	 * Importer page.
	 */

	domReady(function () {
	  // Delegate event
	  jQuery('.kalium-demos').on('click', '.kalium-demos__content-pack-entry-link', function (ev) {
	    ev.preventDefault(); // Popup

	    var link = jQuery(this).data('link'),
	        contentPackId = jQuery(this).closest('[data-content-pack-id]').data('content-pack-id'),
	        popup = new Popup(link, {
	      minWidth: 780,
	      minHeight: 350,
	      maxHeight: 750,
	      dismissOverlay: false
	    }); // Popup content loaded

	    jQuery(popup).on('popup.load', function (ev, content, container) {
	      // Initialize Kalium Import class
	      var importer = new Kalium_Import(contentPackId, container, popup);
	    }); // Open popup

	    popup.open();
	  }); // Hover thumbnail

	  jQuery('.kalium-demos .kalium-demos__content-pack-entry-image').each(function (i, el) {
	    // Thumbnail
	    var $imageContainer = jQuery(el),
	        $image = $imageContainer.find('img');
	    $image.on('load', function () {
	      var imageHeight = $image.outerHeight(),
	          scrollHeight = imageHeight - $imageContainer.outerHeight();

	      if (scrollHeight > 40) {
	        var duration = scrollHeight / 250;
	        $image.css('transition-duration', "".concat(duration, "s")); // Mouse over

	        $imageContainer.on('mouseover', function () {
	          $image.css('transform', "translateY(-".concat(scrollHeight, "px)"));
	        }); // Mouse out

	        $imageContainer.on('mouseout', function () {
	          $image.css('transform', "translateY(0px)");
	        });
	      }
	    });
	  });
	});

})));
